function [HHElas,BaseCost,HHShare,HHIncome] = ...
    AnalyzeResults(ParameterFile,tSample,SampleSize,iSample, ...
                   BootstrapDir,brep,xFreeBoot)
%
% Revision history
%
% 2017MAR18   Cleaned version for publication.
%
% This file is to be run after estimation
% 
% Variable                               Source (where it is defined)
%------------------------------------------------------------------
% ParameterFile                          Input
%
% OutDir                                 Parameter file
% EstimationResultsMatFile               Parameter file
% OutSideOptionCode                      Parameter file
% SaveDataFile                           Parameter file
% FirmDataFile                           Parameter file
% BaseTaxDataFile                        Parameter file
% IncludeOutsideOption                   Parameter file
% noptions    				             Parameter file
% EstColumn                              Parameter file
% RawColumn              			     Parameter file
% ZIndex                                 Parameter file
% RCDim                                  Parameter file
% ElasticityMatFile			             Parameter file
% ElasticityTxtFile1			         Parameter file
% ElasticityTxtFile2			         Parameter file
% 
%
% nHH                                    SaveDataFile
% HHProductCodeRaw                       SaveDataFile
% HHCode			  	                 SaveDataFile
% basis                                  SaveDataFile
% data                                   SaveDataFile
% BrandDummies                           SaveDataFile
%
% xFree2                                 EstimationResultsMatFile
% iFree2 				                 EstimationResultsMatFile
% beta2					                 EstimationResultsMatFile
% CDiag				                     EstimationResultsMatFile
% COffDiag                               EstimationResultsMatFile
% C                                      EstimationResultsMatFile           
% LogNormalFlag                          EstimationResultsMatFile
% LogNormalIndex                         EstimationResultsMatFile
% basis                                  EstimationResultsMatFile
% Nodes					                 EstimationResultsMatFile
% Weights				                 EstimationResultsMatFile
% nQuadAll                               EstimationResultsMatFile

% Set flags=1 to test various subroutines.
% Set flags=0 for normal run of program.
AnalyzeFlag.UpdatePrice = 0;
AnalyzeFlag.NewData     = 0;
AnalyzeFlag.GradS       = 0;
AnalyzeFlag.HHElas      = 0;          
AnalyzeFlag.nElas       = 48;

% Add directories to path
setpath;

% Evaluate parameter file to load parameter values
eval(ParameterFile);

if exist(EstimationResultsMatFile,'file')~=2
  disp('Estimation results file not found. Tax Results cannot be computed.');
  disp('First run main.m which creates this file. Then run AnalyzeResults1.');
end

% load EstimationResultsMatFile
% Contains:
%     'xFree2',      ...
%     'iFree2',      ...
%     'beta2',       ...
%     'CDiag',       ...
%     'COffDiag',    ...
%     'C',           ...
%     'LogNormalFlag', ...
%     'LogNormalIndex', ...
%     'Nodes',       ...
%     'Weights',     ...
%     'nQuadAll');

load(EstimationResultsMatFile);
if nargin==1
   rng('default');
   SampleSize = 1000;
   % Select random subsample for calculations
   e1     = rand(nHH,1);
   e1sort = sort(e1);
   iSample = e1<=e1sort(SampleSize);
   tSample = rand(nHH,1);  % there are nT observations per HH
                           % this is used to select one random obs. per HH
end

if nargin>4
  % set parameter values to values of current bootstrap draw  
  xFree2 = xFreeBoot;
  % define file names for bootstrap results
  [~,BaseTaxDataFile,CostDataFile,SortedDataFile,ElasticityMatFile, ...
   ElasticityTxtFile1,ElasticityTxtFile2] = ...
          SetBootstrapFilenames(BootstrapDir,brep);  
end

%% Load data for profit and elasticity calculations
% File contains:
%   data,
%   nHH
%   HHCode
%   HHProductCodeRaw
%   basis
%   BrandDummies
load(SaveDataFile);

if (nT>1)
  % select one observation per HH
  % e1 chooses one random observation per HH
  if ~exist('tSample','var')
    tSample = rand(nHH,1);
  end
  e1 = kron(ceil(nT*tSample),ones(noptions*nT,1));
  e2 = kron(ones(nHH,1),kron((1:5)',ones(noptions,1)));
  data             = data(e1==e2,:);
  HHCode           = HHCode(e1==e2);
  HHProductCodeRaw = HHProductCodeRaw(e1==e2);
  BrandDummies     = BrandDummies(e1==e2,:);
  if basis.EquivalenceScaleFlag==1
    basis.EquivalenceScale=basis.EquivalenceScale(e1==e2);
  end
  nT = 1;
end

% Empirical market shares
EmpiricalShare = zeros(noptions,1);
choice         = data(data(:,RawColumn.Choice)==1,RawColumn.ProductCode);
ProductList    = sort(data(1:noptions,RawColumn.ProductCode));
for i1=1:noptions
  EmpiricalShare(i1) = mean(choice==ProductList(i1));
end

% when testing choose AnalyzeFlag.Subsample==1 to select a subset of data
if SampleSize>0
  % construct random subsample of households
  nHH1 = SampleSize;
  if ((SparseGridFlag==2 || SparseGridFlag==3) && MCDrawFlag==2)
    % Monte carlo integration nodes
    % different draws for each HH
    % Nodes = (nHH*nQuadAll,RCDim)
    Nodes = reshape(Nodes,[nHH nQuadAll RCDim]);
    Nodes = reshape(Nodes(iSample,:,:),[nHH1*nQuadAll RCDim]);
  end
  
  % resize(i2) = (nHH1*noptions,1)
  i2 = repmat(iSample',[noptions,1]);
  i2 = i2(:);
  data             = data(i2,:);
  HHCode           = HHCode(i2);
  HHProductCodeRaw = HHProductCodeRaw(i2);
  BrandDummies     = BrandDummies(i2,:);
  if basis.EquivalenceScaleFlag==1
      basis.EquivalenceScale=basis.EquivalenceScale(i2);
  end
  nHH              = SampleSize;
end

% Load data on firm ownership of products
FirmData=importdata(FirmDataFile);

if size(FirmData.textdata,1)>1
  OwnershipMatrix=FirmData.data;
  ProductCodeRaw=str2double(FirmData.textdata(2:noptions+1,1));
else
  OwnershipMatrix= FirmData.data(:,4:size(FirmData.data,2));
  ProductCodeRaw = FirmData.data(:,1);  
end
nFirms=size(OwnershipMatrix,2);
  
if IncludeOutsideOption==1
  % Assume column 1 is outside option: check that assumption is true
  if any(OwnershipMatrix(ProductCodeRaw~=OutsideOptionCode,OutsideOptionColumn)==1) ...
     ||  OwnershipMatrix(ProductCodeRaw==OutsideOptionCode,OutsideOptionColumn)~=1
    disp('Data in OutsideOptionColumn of OwnershipMatrix is not consistent with Outside Option.')
    disp('OutsideOptionColumn of OwnershipMatrix must contain data for Outside Option.')
    return
  end
end

% Create HHFirmCode: FirmCode mapped to HH level data
% Create FirmCode:   code number firm
% Renumber HHProductCodeRaw and ProductCodeRaw so that they are integers from 1 - noptions
%
HHProductCode=zeros(noptions*nHH,1);
HHFirmCode=zeros(noptions*nHH,1);
ProductCode=zeros(noptions,1);
FirmCode=zeros(noptions,1);
for j=1:noptions
  f=find(OwnershipMatrix(j,:)==1);
  HHProductCode(HHProductCodeRaw==ProductCodeRaw(j))=j;
  HHFirmCode(HHProductCodeRaw==ProductCodeRaw(j))=f;
  ProductCode(ProductCodeRaw==ProductCodeRaw(j))=j;
  FirmCode(ProductCodeRaw==ProductCodeRaw(j))=f;
end
clear HHProductCodeRaw;

% Sort household level data by (HHCode, HHFirmCode, HHProductCode)
[temp,HHSortIndex]  = sortrows([HHCode HHFirmCode HHProductCode],[1 2 3]);
SortedHHCode        = temp(1:noptions:(nHH-1)*noptions+1,1);
SortedHHFirmCode    = temp(:,2);
SortedHHProductCode = temp(:,3);
SortedData          = data(HHSortIndex,:);
BrandDummies        = BrandDummies(HHSortIndex,:);
clear data temp HHSortIndex HHCode HHFirmCode HHProductCode;

% Save SortedData to disk
save(SortedDataFile,'-v7.3','SortedData');

% Sort product level data by (FirmCode, ProductCode)
[temp,SortIndex]     = sortrows([FirmCode ProductCode],[1 2]);
SortedFirmCode       = temp(:,1);
SortedProductCode    = temp(:,2);
SortedProductCodeRaw = ProductCodeRaw(SortIndex);

% Renumber product codes in HH level data
NewHHProductCode=zeros(noptions*nHH,1);
for j=1:noptions
  NewHHProductCode(SortedHHProductCode==SortedProductCode(j))=j;
end
clear SortedHHProductCode;

AllFirmsProducts=cell(nFirms,1);
AllCompetitorProducts=cell(nFirms,1);
for f=1:nFirms
  AllFirmsProducts{f}=find(SortedFirmCode==f);
  AllCompetitorProducts{f}=find(SortedFirmCode~=f);
end

% Create HHProductCodeList: A cell array listing the rows in the HH dataset
%                           corresponding to each product
HHProductCodeList=cell(noptions,1);
for j=1:noptions
  HHProductCodeList{j}=find(NewHHProductCode==j);
end

% Create X and Z for use in calculating elasticities, shares and costs
[X,Z] = NewData(SortedData,BrandDummies, ...
                RawColumn,basis,ZIndex,  ...
                nHH,noptions);

if AnalyzeFlag.UpdatePrice==1
  NewDataHandle = @(data)NewData(data,BrandDummies,      ...
                                 RawColumn,basis,ZIndex, ...
                                 nHH,noptions);
  iNonZero = SortedData(:,RawColumn.Price)>0;
  UpdatePriceHandle = ...
      @(expenditure)UpdatePriceTerms(expenditure,X,Z,basis,EstColumn, ...
                                     ZIndex,iNonZero,RCDim);
  e = TestUpdatePrice(SortedData,RawColumn,ZIndex, ...
                      NewDataHandle,UpdatePriceHandle);    
end

if AnalyzeFlag.NewData==1
  NewDataHandle =   @(data)NewData(data,BrandDummies, ...
                                   RawColumn,basis,ZIndex, ...
                                   nHH,noptions);
  e =TestNewData(SortedData,X,Z,NewDataHandle,RawColumn,basis,ZIndex);    
end
                                
MarketShareHandle = ...
      @(X,Z)MarketShare(X,Z, ...
                        xFree2,iFree2,beta2,CDiag,COffDiag, ...
                        LogNormalFlag,LogNormalIndex,       ...
                        EstColumn,ZIndex,        ...
                        noptions,nHH,RCDim,RCRank, ...
                        nFirms,AllFirmsProducts, ...
                        NewHHProductCode, ...
                        Nodes,Weights,nQuadAll);

Tax.Type=1;
% Data on saturated fat content  (first noptions rows only)
Sats=SortedData(1:noptions,RawColumn.Sats);

MarketShare2Handle = ...
      @(X,Z)MarketShare2(X,Z,...
                         xFree2,iFree2,beta2,CDiag,COffDiag, ...
                         LogNormalFlag,LogNormalIndex,       ...
                         EstColumn,ZIndex, ...
                         noptions,nHH,RCDim,RCRank, ...
                         nFirms,AllFirmsProducts, ...
                         NewHHProductCode, ...
                         Nodes,Weights,nQuadAll,Tax, ...
                         Sats,AllCompetitorProducts);

%% Test calculation of gradient of shares
if AnalyzeFlag.GradS==1
  % Calculate BASELINE shares, gradient of shares
  [HHShare,HHGradS] = MarketShareHandle(X,Z);
  
  rows=(1:noptions)';
  rows = rows(SortedProductCodeRaw~=OutsideOptionCode);
  % Compute HHGradS1(j,:,:) for each j in rows
  ExitFlag = TestMarketShareAll(MarketShareHandle, ...
                                MarketShare2Handle, ...
                                rows,noptions,nHH,  ...
                                X,Z,basis,EstColumn,ZIndex, ...
                                RCDim);
  clear HHGradS1 HHShare HHGradS HHProductCodeList;                       
end    % if TestGradS==1

ComputeElasticity=1;
if ComputeElasticity==1
%% Calculate elasticities for each HH
HHElas=Elasticity(X,Z,xFree2,iFree2,beta2,CDiag,COffDiag, ...
                  LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                  noptions,nHH,RCDim,RCRank,NewHHProductCode,  ...
                  Nodes,Weights,nQuadAll,basis.ExpendFlag);

if AnalyzeFlag.HHElas==1
  nTest=AnalyzeFlag.nElas;
  e = zeros(nTest,1);
  HHElas1 = zeros(size(HHElas));
  for j=1:nTest
    rows=j;
    % Compare computed HHElas to version computed using numerical
    % derivatives

    % First compute HHShare
    HHShare = MarketShareHandle(X,Z);

    iNonZero = (X.Price>0);
    UpdatePriceHandle = ...
    @(expenditure)UpdatePriceTerms(expenditure,X,Z,basis,EstColumn, ...
                                   ZIndex,iNonZero,RCDim);

    temp=TestElasticity(MarketShareHandle,UpdatePriceHandle, ...
                                X,HHShare,rows,noptions,nHH);
    % temp = negative of elasticity
    if basis.ExpendFlag==1
      HHElas1(rows,:,:) = -temp;                                 
    end
    temp = squeeze(HHElas1(j,:,:)-HHElas(j,:,:));                   
    e(j) = max( abs(temp(:)));
  end   % for j=1:5
end     % if TestHHElas==1

if isempty(RawColumn.SampleWeight)
  HHWeights = ones(noptions,nHH);
else
  HHWeights = reshape(SortedData(:,RawColumn.SampleWeight),noptions,nHH);
end
Choice    = SortedData(:,RawColumn.Choice);
[HHShare,HHGradS]   = MarketShareHandle(X,Z);

[Market,nHH] = DefineMarket(SortedData,RawColumn,MarketDefinition, ...
                            noptions,nMonths,nRegions);
[HHPrice,BasePrice] = ...
    ComputeBasePrice(PriceOption,SortedData,RawColumn,     ...
                     MarketShareHandle,X,Z,Market,         ...
                     basis,EstColumn,ZIndex,               ...
                     noptions,RCDim,nMarkets,nRegions,     ...
                     SortedProductCodeRaw,OutsideOptionColumn,   ...
                     PriceDataFile,MarketDefinition);

if basis.ExpendFlag==1
  % utility depends on f(y-p): multiply HHGradS by negative 1
  t1=-1;
elseif basis.ExpendFlag==0
    % utility depends on -f(p)
    t1=1;
end
[BaseCost,HHCost]=ComputeCosts(HHShare,t1*HHGradS,HHWeights,BasePrice,  ...
                               noptions,nHH,nFirms,AllFirmsProducts, ...
                               Market(SortedData(:,RawColumn.Choice)==1), ...
                               nMarkets,OutsideOptionColumn);

save(CostDataFile,'BaseCost','HHCost');                             
      
% Save elasticities in ElasFile
HHIncome = SortedData(:,RawColumn.Expenditure) + SortedData(:,RawColumn.Price);
save(ElasticityMatFile,'HHElas',               ...
                       'HHShare',              ...
                       'HHPrice',              ...
                       'HHIncome',             ...
                       'Choice',               ...
                       'HHWeights',            ...
                       'Market',               ...
                       'SortedHHCode',         ...
                       'SortedFirmCode',       ...
                       'SortedProductCodeRaw', ...
                       '-v7.3');
clear SortedHHCode BrandDummies;

% Compute summary statistics of elasticities
Share=mean(reshape(Choice,noptions,nHH),2);
ElasAvg=mean(HHElas,3);
Elas50=median(HHElas,3);
ElasStd=std(HHElas,0,3);
Elas10=quantile(HHElas,0.1,3);
Elas90=quantile(HHElas,0.9,3);
MedianCost = median(BaseCost,2);
MeanPrice = mean(reshape(HHPrice,noptions,nHH),2);

% Compute Market Elasticities

% Print summary statistics on elasticities to file named:
%     ElasticityTxtFile1
fid=fopen(ElasticityTxtFile1,'w');
fprintf(fid,'%s\n','Own Price Elasticities');
fprintf(fid,'%8s','Firm');
fprintf(fid,'%9s','Product');
fprintf(fid,'%9s','Share 1');
fprintf(fid,'%9s','Share 2');
fprintf(fid,'%9s','Price');
fprintf(fid,'%9s','Cost');
fprintf(fid,'%9s','Mean');
fprintf(fid,'%9s','Median');
fprintf(fid,'%9s','Std.');
fprintf(fid,'%12s','10th pct.');
fprintf(fid,'%12s','90th pct.');
fprintf(fid,'\n');
for j=1:noptions
  fprintf(fid,'%8.0f %8.0f %8.3f %8.3f %8.3f %8.3f %8.2f %8.2f %8.2f %11.2f %11.2f', ...
    [SortedFirmCode(j) SortedProductCodeRaw(j) EmpiricalShare(j) Share(j), ...
     MeanPrice(j),MedianCost(j), ...
     ElasAvg(j,j) Elas50(j,j) ElasStd(j,j) Elas10(j,j) Elas90(j,j)]);
  fprintf(fid,'\n');
end
fclose(fid);

% Print Cross Price Elasticities to ElasticityTxtFile2
fid=fopen(ElasticityTxtFile2,'w');
fprintf(fid,'%s\n','Selected Cross Price Elasticities');
fprintf(fid,'%s\n\n','(Product 1 = Biggest Cross price Elasticity, Product 2 = 2nd Biggest, etc.)');

fprintf(fid,'%9s','Product');
fprintf(fid,'%11s','Product 1');
fprintf(fid,'%11s','Mean');
fprintf(fid,'%11s','Product 2');
fprintf(fid,'%11s','Mean');
fprintf(fid,'%13s',['Product ',int2str(noptions-1)]);
fprintf(fid,'%13s','Mean');
fprintf(fid,'%13s',['Product ',int2str(noptions)]);
fprintf(fid,'%13s','Mean');

fprintf(fid,'\n');
for j=1:noptions
  temp=ElasAvg(:,j);
  temp(j)=-1e20;
  [e1,i1]=sort(temp);
  fprintf(fid,'%9.0f %10.0f %10.4f %10.0f %10.4f %12.0f %12.4f %12.0f %12.4f', ...
    [SortedProductCodeRaw(j), ...
     SortedProductCodeRaw(i1(noptions)),   e1(noptions),   ...
     SortedProductCodeRaw(i1(noptions-1)), e1(noptions-1), ...
     SortedProductCodeRaw(i1(3)),          e1(3),          ...
     SortedProductCodeRaw(i1(2)),          e1(2)]);
  fprintf(fid,'\n');
end
fclose(fid);
end  % if ComputeElasticity==1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% In data, 
%%     price = (actual price)               when Choice==1
%%     price = (avg. price in region,month) when Choice==0
%% For Choice==1, replace (actual price) with (avg. price in region,month)

if nT==1
  hhid=SortedData(SortedData(:,RawColumn.Choice)==1,RawColumn.HH)';
elseif nT>1
  hhid=SortedData(SortedData(:,RawColumn.Choice)==1,RawColumn.HHTimePeriod)';
end
Treated=zeros(size(SortedData,1),1);

GrossExpenditure = SortedData(:,RawColumn.Expenditure) ...
                 + SortedData(:,RawColumn.Price);
for i1 = hhid
  % Get index of current HH  
  if nT==1
    iHH = (SortedData(:,RawColumn.HH)==i1 & SortedData(:,RawColumn.Choice)==1);
  else
    iHH = (SortedData(:,RawColumn.HHTimePeriod)==i1 & ...
           SortedData(:,RawColumn.Choice)==1);
  end
  
  if Treated(iHH)==0
    % Current (month,region,product)
    m   = SortedData(iHH,RawColumn.Month);
    if ~isempty(RawColumn.Region)
      r   = SortedData(iHH,RawColumn.Region);
    end
    p   = SortedData(iHH,RawColumn.ProductCode);

    if p~=OutsideOptionCode
      % Find ALL households with same (m,r,p) as current HH and with choice==1
      if isempty(RawColumn.Region)
        i3=(SortedData(:,RawColumn.Choice)      == 1  & ...
            SortedData(:,RawColumn.Month)       == m  & ...
            SortedData(:,RawColumn.ProductCode) == p);
      % Find ALL households with same (m,r,p)  and choice==0
      i4=(SortedData(:,RawColumn.Choice)      == 0  & ...
          SortedData(:,RawColumn.Month)       == m  & ...
          SortedData(:,RawColumn.ProductCode) == p);
      else
        i3=(SortedData(:,RawColumn.Choice)      == 1  & ...
            SortedData(:,RawColumn.Month)       == m  & ...
            SortedData(:,RawColumn.Region)      == r  & ...
            SortedData(:,RawColumn.ProductCode) == p);
        % Find ALL households with same (m,r,p)  and choice==0
        i4=(SortedData(:,RawColumn.Choice)      == 0  & ...
            SortedData(:,RawColumn.Month)       == m  & ...
            SortedData(:,RawColumn.Region)      == r  & ...
            SortedData(:,RawColumn.ProductCode) == p);
      end
  
      if sum(i4)>0
         % Reset price of all i3 households
        price=mean(SortedData(i4,RawColumn.Price));
        NetExpenditure = GrossExpenditure(i3)-price;
        if isfield(RawColumn,'Expenditure_X')
          SortedData(i3,RawColumn.Expenditure_X)= ... 
                     SortedData(i3,RawColumn.Expenditure_X) ...
                     .*repmat(NetExpenditure./SortedData(i3,RawColumn.Expenditure), ...
                              [1 length(RawColumn.Expenditure_X)]);
        end
        SortedData(i3,RawColumn.Price)=price;
        SortedData(i3,RawColumn.Expenditure) = NetExpenditure;

        if isfield(RawColumn,'Expenditure2_X')
          SortedData(i3,RawColumn.Expenditure2_X) = ...
              (SortedData(i3,RawColumn.Expenditure2_X)./ ...
               repmat(SortedData(i3,RawColumn.Expenditure2),[1 EstColumn.k2])) ...
               .*NetExpenditure.^2;
        end
        if isfield(RawColumn,'Expenditure2')
          SortedData(i3,RawColumn.Expenditure2) = NetExpenditure.^2;
        end
        if isfield(RawColumn,'Expenditure3_X')
          SortedData(i3,RawColumn.Expenditure3_X) = ...
              (SortedData(i3,RawColumn.Expenditure3_X)./ ...
               repmat(SortedData(i3,RawColumn.Expenditure3),[1 EstColumn.k3])) ...
               .* NetExpenditure.^3;
        end
        if isfield(RawColumn,'Expenditure3')
          SortedData(i3,RawColumn.Expenditure3) = NetExpenditure.^3;
        end
      elseif sum(i4)==0
        price=mean(SortedData(i3,RawColumn.Price));
        NetExpenditure = GrossExpenditure(i3) - price;
        if isfield(RawColumn,'Expenditure_X')
          SortedData(i3,RawColumn.Expenditure_X)= ... 
                     SortedData(i3,RawColumn.Expenditure_X) ...
                     .*repmat(NetExpenditure./SortedData(i3,RawColumn.Expenditure), ...
                              [1 length(RawColumn.Expenditure_X)]);
        end
        SortedData(i3,RawColumn.Price)=price;
        SortedData(i3,RawColumn.Expenditure) = NetExpenditure;
        if isfield(RawColumn,'Expenditure2_X')
          SortedData(i3,RawColumn.Expenditure2_X) = ...
               (SortedData(i3,RawColumn.Expenditure2_X)./ ...
                repmat(SortedData(i3,RawColumn.Expenditure2),[1 EstColumn.k2])).* ...
                ones(length(i3),EstColumn.k2).*NetExpenditure.^2;
        end
        if isfield(RawColumn,'Expenditure2')
          SortedData(i3,RawColumn.Expenditure2) = NetExpenditure.^2;
        end
        if isfield(RawColumn,'Expenditure3_X')
          SortedData(i3,RawColumn.Expenditure3_X) = ...
               (SortedData(i3,RawColumn.Expenditure3_X)./ ...
                repmat(SortedData(i3,RawColumn.Expenditure3),[1 EstColumn.k3])).* ...
                ones(length(i3),EstColumn.k3).*NetExpenditure.^3;
        end
        if isfield(RawColumn,'Expenditure3')
          SortedData(i3,RawColumn.Expenditure3) = NetExpenditure.^3;
        end
      end
      Treated(i3)=1;
    end
  end    
end
clear Treated hhid iHH i3 i4;

save(BaseTaxDataFile,'-v7.3', ...
     'SortedData',            ...
     'basis',                 ...
     'nHH',                   ...
     'OwnershipMatrix',       ...
     'ProductCodeRaw',        ...
     'SortedProductCodeRaw',  ...
     'SortedHHFirmCode',      ...
     'SortedFirmCode',        ...
     'xFree2',                ...
     'iFree2',                ...
     'beta2',                 ...
     'CDiag',                 ...
     'COffDiag',              ...
     'nFirms',                ...
     'AllFirmsProducts',      ...
     'AllCompetitorProducts', ...
     'NewHHProductCode',      ...
     'Nodes',                 ...
     'Weights',               ... 
     'nQuadAll');
 display('AnalyzeResults complete.');