function [data,SumStats,VarLabels]=      ...
         CleanData(DataFile,DataHeaderLine,SaveDataFile,SaveDataFlag, ...
         SummaryFile,nHH_Raw,noptions,nvars,nT,nHH,                   ...
         HHIndex,ChoiceIndex,ProductCodeIndex)
%
% Load and clean data.
%
% Revision history
%
% 2017MAR18    revised and cleaned for QE.
%
% Data format (See XXX.log)
%
%
%  Set path to tools
if exist('SumStat.m','file')~=2
  path(path,'tools')
end

% Set state for uniform random number generator
%rand('twister', 5489);
rng('default');
  
%  Load data into Matlab
%  Store data in matrix

TotalTime=0;
% if nHH>0, then select a sample of observations of 
% size = nHH
if nHH<nHH_Raw
  index=randperm(nHH_Raw);
  index=sort(index(1:nHH));
  data.data=zeros(noptions*nHH*nT,nvars);
  
  fid = fopen(DataFile);
  
  counter=0;
  for i1=index
    DataPosition=nT*noptions*counter;
    counter=counter+1;
    for t=1:nT
    for j1=1:noptions
      if i1==index(1) && j1==1 && t==1
        % Skip top line which contains labels
        nSkip=1+nT*noptions*(i1-1);
      elseif i1>index(1) && j1==1 && t==1
        LastHH=index(counter-1);
        nSkip=nT*noptions*(i1-LastHH-1)+1;
      else
        nSkip=0;
      end
      tic
      temp=textscan(fid,'%n',nvars,       ...
                    'HeaderLines',nSkip, ...
                    'Delimiter',',', ...
                    'CollectOutput',1);
      data.data(DataPosition+(t-1)*noptions+j1,:)=temp{1}';
      TotalTime=TotalTime+toc/60;
      disp([(DataPosition+(t-1)*noptions+j1)/(nT*noptions*nHH) TotalTime]);
    end  % for j1=1:noptions
    end  % for t=1:nT
  end
  fclose(fid);
  ErrFlag=TestDataLoad(data.data,nHH*nT,noptions,HHIndex,ChoiceIndex, ...
                       ProductCodeIndex);
 
  if any(ErrFlag~=0)
    disp('There was an error loading the data.');
    disp(ErrFlag)
    keyboard;
  end
  
elseif nHH==nHH_Raw
  data.data=dlmread(DataFile,',',DataHeaderLine,0);
end
%  Read in variable labels
%        1  2  3  4  5  6  7  8  9  10
base='%s ';
fstr=repmat(base,[1 nvars]);

fid=fopen(DataFile);
colheaders=textscan(fid,fstr,1,'delimiter',',');
data.colheaders=cell(nvars,1);
for i=1:nvars
  str=colheaders{i};
  data.colheaders{i}=str{1};
end
fclose(fid);

[SumStats,VarLabels]=SummaryStatistics(data,HHIndex,ChoiceIndex);
PrintSumStats(SumStats,VarLabels,SummaryFile);

%  Save data to matlab format .mat file.
if SaveDataFlag==1
  save(SaveDataFile,'data','nHH','nT','noptions','SumStats','VarLabels','-v7.3');
end
% Change permissions on datafile
if isunix==1 && SaveDataFlag==1
  system(['chmod 0770 ',SaveDataFile]);
end