function [f,df,d2f]=ComputeBasisFunctions(e,basis) 
% e =   p        Case 1
%   =   y-p      Case 2
%
% Revision history
% 2017MAR18  cleaned version for QE

if basis.EquivalenceScaleFlag==1
  e = e./basis.EquivalenceScale;    
end
if basis.flag==1 
  % f(e) = [e e.^2 e.^3]
  d2f = [zeros(length(e),1), 2*ones(length(e),1) 6*e]';
  df  = [ones(length(e),1) 2*e 3*e.*e]';
  f   = [e e.^2 e.^3]';
elseif basis.flag==2
  % f(e) = [B1(e),...BN(e)]  b-splines
  sorted=0;
  [f,df,d2f]=bspline5(e,basis.knots,basis.k,sorted);
elseif basis.flag==3
  e = TransformExpenditure(e,basis);
  [f,df,d2f]=cheb(e,basis.k,basis.nodes);  
  f   = f(2:basis.k+basis.nodes,:);
  df  = df(2:basis.k+basis.nodes,:)*(2/(basis.MaxP-basis.MinP));
  d2f = d2f(2:basis.k+basis.nodes,:)*(2/(basis.MaxP-basis.MinP))*(2/(basis.MaxP-basis.MinP));
elseif basis.flag==4
  % linear in expenditure
  f   = e.';
  df  = ones(1,size(e,1));
  d2f = zeros(1,size(e,1));
elseif basis.flag==5
  % log of expenditure
  f = zeros(1,size(e,1));
  df = f;
  d2f = f;
  small=1e-4;
  i1 =e>=small;
  i2 =e<small;
  if any(i1)
    f(i1) = log(e(i1)).';
    df(i1) = 1./e(i1).';
    d2f(i1) = -df(i1)./e(i1).';
  end
  if any(i2)
    f(i2) = (log(small) + (e(i2)-small)/small +0.5*(e(i2)-small).*(e(i2)-small)/(small^2)).';
    df(i2) = (1/small - (e(i2)-small)/(small^2)).';
    d2f(i2) = -1/(small^2);
  end
elseif basis.flag==6
  % polynomial in log of expenditure
  small=1e-4;
  f = zeros(size(e,1),3);
  df = f;
  d2f = f;
  i1 = e>=small;
  i2 = e<small;
  if any(i1)
    f1 = log(e(i1));  
    f(i1,:)   = [f1 f1.*f1 f1.*f1.*f1];
    df(i1,:)  = [1./e(i1) 2*f1./e(i1) 3*f(i1,2)./e(i1)];
    d2f(i1,:) = [-df(i1,1)./e(i1) 2*(1-f1)./(e(i1).*e(i1)) , ...
                 3*(2*f1 - f(i1,2))./(e(i1).*e(i1))]; 
  end
  if any(i2)
    x1 = e(i2)-small;
    x2 = x1.*x1;
    d2f(i2,1) = -1/(small^2);
    df(i2,1)  = 1/small;
    f(i2,1)   = log(small) + df(i2,1).*x1 + 0.5*d2f(i2,1).*x2;
    df(i2,1)  = df(i2,1) + d2f(i2,1).*x1;
    
    d2f(i2,2) = 2*(1-log(small))/(small^2);
    df(i2,2)  = 2*log(small)/small;
    f(i2,2)   = log(small)^2 + df(i2,2).*x1 + d2f(i2,2).*x2;
    df(i2,2)  = df(i2,2) + d2f(i2,3).*x1;
    
    d2f(i2,3) = 3*log(small)*(2-log(small))/(small^2);
    df(i2,3)  = 3*log(small)^2/small;
    f(i2,3)   = log(small)^3 + df(i2,3).*x1 + d2f(i2,3).*x2;
    df(i2,3)  = df(i2,3) + d2f(i2,3).*x1;
  end
  f=f.';
  df=df.';
  d2f=d2f.';
elseif basis.flag==7
  % f(e) = [B1(e),...BN(e)]  b-splines
  sorted=0;
  nSplice = size(basis.nKnots,1); % number of spline spaces to be spliced
                                  % together
  ne = size(e,1);
  f = zeros(sum(basis.n),ne);
  df = f;
  d2f = f;
  first=1;
  for i1=1:nSplice
    [TempF,TempDF,TempD2F]=bspline5(e,basis.knots{i1},basis.k(i1),sorted);
    last = first+basis.n(i1)-1;
    f(first:last,:) = TempF;
    df(first:last,:) = TempDF;
    d2f(first:last,:) = TempD2F;
    first = last+1;
  end  
end

if basis.EquivalenceScaleFlag==1
   % u     = f( e/N)
   % D1F_DE = df/de * (1/N)
   % D2F_DE = D2F/DE2 * (1/N)*(1/N)
   % size(df)  = (k x N)
   % size(D2F) = (k x N)
   K=size(df,1);
   df = df ./ repmat(basis.EquivalenceScale.',[K 1]);
   d2f =d2f ./ repmat((basis.EquivalenceScale.^2).',[K 1]);
end