function [DeltaX,TempZ,NotIdentifiedBrands,basis] = ...
    CreateDeltaX(data,BrandDummies,RawColumn,ZIndex,basis, ... 
                 N,J,RCDim)                                   
%
% Revision history
% 2017MAR18   QE version

% Check whether all brands are purchased at least once
% Those that are never purchases are listed in: NotIdentifiedBrands
NotIdentifiedBrands=CheckBrands( BrandDummies(data(:,RawColumn.Choice)==1,:) );

% Extract regressors from data
nRegressors=length(RawColumn.Regressors);

% Location in data matrix of NotID_Brands is shifted by nRegressors
NotIdentifiedBrands = NotIdentifiedBrands+nRegressors;  

% f   = (J*N x nf)  f(:,i1) = B(p,i1) where B(:,i1) is the i1'th basis function
% df  = (J*N x nf)  gradient of f w.r.t. p 
% d2f = (J*N x nf)  hessian of f w.r.t. p
% expenditure = TotalExpenditure - price
expenditure = data(:,RawColumn.Expenditure);
price       = data(:,RawColumn.Price);
if basis.EquivalenceScaleFlag==0
  TempExp = expenditure;
elseif basis.EquivalenceScaleFlag==1
  TempExp = expenditure./data(:,RawColumn.EquivalenceScale);
end
basis.MinP = min(TempExp);
basis.MaxP = max(TempExp);

iNonZero = (price>0);
iZero    = (price==0);

if basis.flag==2
  KnotFlag=basis.KnotFlag;
  basis.knots = zeros(basis.nKnots,1);
  if KnotFlag==1
    basis.knots(2:basis.nKnots) = quantile(TempExp(iNonZero), ...
                                         linspace(0,1,basis.nKnots-1)');
    basis.knots(1) = 0;
    basis.knots(basis.nKnots) = max(basis.knots(basis.nKnots), ...
                                    max(TempExp));
  elseif KnotFlag==2
    basis.knots = quantile(TempExp,linspace(0,1,basis.nKnots)');
  elseif KnotFlag==3
    if basis.nKnots==3  
      basis.knots = [.3;2;3.8];
    elseif basis.nKnots==4
      basis.knots = [.5;.75;1;2];
    else
      basis.knots = linspace(.1,3.5,basis.nKnots)';    
    end
  elseif KnotFlag==4
    if basis.nKnots==3
        basis.knots = [0;2;3.8];
    end
  end
elseif basis.flag==3
  % Chebyshev polynomials.
  %    1) transform expenditure to the interval [-1,1]
  %
%  expenditure = TransformExpenditure(expenditure,basis);
%  expenditure = 2*(expenditure-basis.MinP)/(basis.MaxP-basis.MinP)-1;
elseif basis.flag==7
  % [x0,x1]  linear spline
  % [x1,x2]  cubic spline
  % [x2,x3]  linear spline 
  nSplice = size(basis.nKnots,1); % number of splines spaced to be 
                                  % spliced together
  q = linspace(0,1,sum(basis.nKnots)-nSplice+1)';        
  TempKnots = quantile(TempExp,q);
  
  basis.knots = cell(nSplice,1);
  first = 1;
  for i1=1:nSplice
    last = first+basis.nKnots(i1)-1;
    basis.knots{i1} = TempKnots(first:last);
    first=last;    
  end
end

if basis.EquivalenceScaleFlag==1
 basis.EquivalenceScale = data(:,RawColumn.EquivalenceScale);
end

% ComputeBasisFunctions: input is unscaled epxenditure
%                        this function rescales e if necessary
f=ComputeBasisFunctions(expenditure,basis);

f=f';
if basis.ZeroPriceFlag==1
  f(iZero,:)=0;
end
nx = size(RawColumn.Interaction,1); 
basis.nf = size(f,2); 

% DeltaX = [f(p).*x2 x1 BrandDummies ]
x1 = zeros(N*J,(nx+1)*basis.nf);
for i1=0:nx
for i2=1:basis.nf
    index = i1*basis.nf+i2;
  if i1==0
    x1(:,index) = f(:,i2);
  else
    x1(:,index) = f(:,i2).*data(:,RawColumn.Interaction(i1));
  end
end
end
DeltaX = [x1, data(:,RawColumn.Regressors), BrandDummies];
[~,k]=size(DeltaX); 

% Reshape DeltaX to size (noptions x nHH x k)
DeltaX=reshape(DeltaX,J,N,k);

% For each household and for each variable, subtract off
% the corresponding variable for the product chosen.
DeltaX=DeltaX-repmat(DeltaX(J,:,:),[J 1 1]);
DeltaX=reshape(DeltaX,J*N,k);
DeltaX=sparse(DeltaX);

% Extract TempZ:   Data to be interacted with random coefficients
% size(TempZ)           = (N*J x RCDim)
% TempZ(:,ZIndex.iP)    = elements of TempZ that depend on f(price)
% TempZ(:,ZIndex.iNonP) = elements of TempZ that do not depend on price
% f(:,Zindex.iF)        = columns of f that are interacted with random coefficients
% data(:,ZIndex.RawColumn) = elements of data to interact with random coefficients
TempZ=[f(:,ZIndex.iF) data(:,ZIndex.RawColumn)];

% Reshape TempZ to size (J x N x RCDim)
if RCDim>0
  TempZ=reshape(TempZ,J,N,RCDim);
  
  % For each household and for each variable, subtract off
  % the corresponding variable for the product chosen.
  TempZ=TempZ-repmat(TempZ(J,:,:),[J 1 1]);
  TempZ=reshape(TempZ,J*N,RCDim);
  TempZ=sparse(TempZ);
else
  TempZ = [];
end