function [SumStats,VarLabels]=SummaryStatistics(data,HHIndex,ChoiceIndex)
% Revision history
% 2017MAR18 compute summary statistics for data

% Matrix to hold summary statistics
% [mean var min max nobs]

% Data is stored in matrix of size (n x k)
[n,k]=size(data.data);

% Create storage for summary statistics and create VarLabels
SumStats=zeros(k,5);
VarLabels=data.colheaders;

% List of all unique hh_id numbers
HHID=data.data(data.data(:,ChoiceIndex)==1,HHIndex);

%   Household ID number: summary statistics
SumStats(1,:)=SumStat(HHID);

% Sort data so that, for each household, the option actually chosen
% is the last option in the choice set.
CheckChoiceData=0;
if CheckChoiceData==1
% Choice of store
% data.data(:,2)
%   1: shopped at this store
%   0: did not shop at this store
%   For each household, check that:
%     1) observation n == 1
%     2) others        == 0
%
% If false sort data
noptions=zeros(length(HHID),1);
for i1=1:length(HHID)
  % Find all households with same HH id number
  disp(int2str(i1))
  sample=data.data(data.data(:,HHIndex)==HHID(i1),:);
  
  % number of observations per household
  noptions(i1)=size(sample,1);

  % if data is not sorted sort it
  if sample(noptions(i1),2)~=1
    warning(['Data not properly sorted. HHID=',int2str(HHID(i1))]);
    [choice,i2]=sort(sample(:,2));
    data.data(data.data(:,HHIndex)==HHID(i1),:)=sample(i2,:);
  end  

  % if choice==1 for more than 1 product, error
  if sum(sample(:,2))~=1
    error(['HHID=',int2str(HHID(i1)),', sum(choice)~=1.'])
  end
end    
end   % if CheckChoiceData==1

% Compute summary statistics for all variables.
SumStats(2:k,:)=SumStat(data.data(:,2:k));