% Revision history
% 2017MAR17  Final version for publication

%--------------------------------------------------------------------------
% This program will run all programs and produce all outputs that are in
% the paper. It also contains instructions for the main sub programs.
%--------------------------------------------------------------------------


% Step 1: Define parameter file.
%    The parameter file contains parameters that define program behaviour
%    including:
%       a) raw input data file location
%       b) list of variables to include in model
%       c) parameters to choose utility functional form
%       d) parameters to choose random coefficients
%       e) output file location
%
%    There are several versions of the parameter file. Each is used to 
%    estimate and analyse one specification in the paper:
%
%    V130.m:       baseline model  (cubic utility)
%    V131.m:       linear utility model
%    V132.m:       preference shifter model
%    V133.m:       linearized utility model
%    V134.m:       log utility model
%    V136.m:       cubic in log price utility model
%
%   To estimate other specfications, edit V130.m. Options include:
%      1) Change the variables included in the model.
%      2) Use higher order polynomials or splines.
%      3) Additional random coefficients
% 
%  More details are described in the parameter files.
%--------------------------------------------------------------------------

% List of all models to be estimated
AllParameterFiles = {'V130'; ...  % baseline parameter file
                     'V131'; ...  %
                     'V132'; ... 
                     'V133'; ...
                     'V134'; ...
                     'V136'};
                 
nModels = size(AllParameterFiles,1);

% Loop through models: estimate each model in list
for i1=1:nModels
  % Set current parameter file.
  ParameterFile = AllParameterFiles{i1};  

  %--------------------------------------------------------------------------
  % 2) Estimate model and save results to disk.
  %--------------------------------------------------------------------------
  main;

  %--------------------------------------------------------------------------
  % 3) Compute elasticities, market shares and costs. Save results to disk.
  %--------------------------------------------------------------------------
  AnalyseResults(ParameterFile);

  % Compute tax results for model 1 only
  if i1==1
    %--------------------------------------------------------------------------
    % 4) Compute tax results:  (baseline,excise tax)
    %     a) prices
    %     b) shares
    %     c) profits
    %     d) welfare
    %
    %     1) baseline ownership, excise tax
    %     2) baseline ownership, ad valorem tax
    %     3) single product firms, no tax
    %     4) single product firms, excise tax
    %     5) single product firms, ad valorem tax
    %--------------------------------------------------------------------------
    ComputeTaxResults_all;
  end
end

% Bootstrap
ParameterFile = 'V130';
%
nreps=100;   % total number of bootstrap replications
task1 = 1;   % first bootstrap replication
task2 = 100; % last bootsrap replication of current run
if (task1<1 || task1 >task2 || task2>nreps)
  error('Must choose task1>=1 and task1<=task2 and task2<=nreps.')
end
eflag = ComputeBootstrap(ParameterFile,task1,task2,nreps);