function [ProducerPrice,Residual,ConsumerPrice] = ...
         MergeResults(Market,Sats,Tax, ...
                      IncludeOutsideOption,OutsideOptionColumn, ...
                      noptions,nHH,nMarkets, ...
                      nProcessors,Subset,TempDir1,OwnershipFlag)
%   [ProducerPrice,Residual,ConsumerPrice] = ...
%         MergeResults(Market,Sats,Tax, ...
%                      IncludeOutsideOption,OutsideOptionColumn, ...
%                      noptions,nHH,nMarkets)                
%
%  Load results from each market m from file and merge.
%  Output matrices containing all results.
%
% Revision history
% 2017MAR19  Cleaned version for publication
     
ProducerPrice=zeros(noptions,nMarkets);   % NashProducerPrice contains 
                                          % the Nash Equilibrium producer 
                                          % prices, one vector for each market
ConsumerPrice=zeros(noptions*nHH,1);    % vector of Nash Consumer prices at (hh,product) level

Residual=zeros(noptions,nMarkets);    % Residual contains the vector of residuals 
                                      % from the equilibrium equation
                                      % one for each market

for pid=1:nProcessors
for m=Subset{pid}
  disp(m);    
  % Rows in data matrix corresponding to current HH's
  iCurrent = Market==m;
  nTemp = sum(iCurrent)/noptions;
  
  if IncludeOutsideOption==0
    iPrice=(1:noptions)';
  elseif IncludeOutsideOption==1
    iPrice=(1:noptions)';
    iPrice=iPrice(iPrice~=OutsideOptionColumn);
  end
  
  % Load current values of:
  %   1) P1   equilibrium prices for current market
  %   2) R1   residual for current market
  
% Load(CurrentOutFile)
%    P1 = current Nash producer price
%    R1 = current residual for equilibrium equation
  CurrentOutFile = fullfile(TempDir1{pid}, ...
           ['Equilibrium_', ...
            int2str(Tax.Type), '_', ...
            int2str(OwnershipFlag),'_', ...
            int2str(m),'.mat']);
  load(CurrentOutFile);

  ProducerPrice(iPrice,m)=P1;       
  Residual(iPrice,m)=R1;
      
  if nTemp==1
    if Tax.Type==1
      ConsumerPrice(iCurrent)=ProducerPrice(:,m)+Tax.tax*Sats;
    elseif Tax.Type==2
      ConsumerPrice(iCurrent)=ProducerPrice(:,m).*(1+Tax.tau*Sats);
    elseif Tax.Type==3
      ConsumerPrice(iCurrent)=ProducerPrice(:,m);
    end
  elseif nTemp>1
    if Tax.Type==1
      ConsumerPrice(iCurrent)=repmat(ProducerPrice(:,m)+Tax.tax*Sats,[nTemp 1]);
    elseif Tax.Type==2
      ConsumerPrice(iCurrent)=repmat(ProducerPrice(:,m).*(1+Tax.tau*Sats),[nTemp 1]);
    elseif Tax.Type==3
      ConsumerPrice(iCurrent)=repmat(ProducerPrice(:,m),[nTemp 1]);
    end
  end
end  % for m=Subset{pid}
end  % for pid=1:nProcessors