function [S,S_SE]=ComputeSE(C,Omega0,iFree2,RCDim)
% function [S,S_SE]=ComputeSE_C(C,Omega0,iFree2,RCDim)
% Compute standard errors of covariance matrix
%
% S        = (RCDIM x RCDIM)   covariance matrix of random coefficients
% S_SE     = (RCDIM x RCDIM)   standard errors of S
% C        = (RCDIM*RCDIM x 1) cholesky decomposition of S
% Omega0   = (nFreeC x nFreeC) covariance matrix of free elements of C
% iFree2.CDiag = cell(2,1)    indexes corresponding to free elements in CDiag
% iFree2.COffDiag = cell(2,1) indexes corresponding to free elements in COffDiag
%                              parms
% RCDim  = (1 x 1)  dimension of random coefficient vector
%
% Revision history
% 2017MAR26  Final version for publication

S=C*C';

nFull = RCDim + RCDim*(RCDim-1)/2;
nOmega0 = size(Omega0,1);

% Omega = covariance matrix of full vector of parameters in C
%         (fixed elements of zero elements in Omega)
if nOmega0==nFull
    Omega=Omega0;
else
  Omega=zeros(nFull,nFull);
  nFreeDiag = size(iFree2.CDiag{1},1);
  
  Omega(iFree2.CDiag{1},iFree2.CDiag{1}) = Omega0(1:nFreeDiag,1:nFreeDiag);
  Omega(iFree2.CDiag{1},iFree2.COffDiag{1}) = Omega0(1:nFreeDiag,nFreeDiag+1:nOmega0);
  Omega(iFree2.COffDiag{1},iFree2.CDiag{1}) = Omega0(nFreeDiag+1:nOmega0,1:nFreeDiag);
  Omega(iFree2.COffDiag{1},iFree2.COffDiag{1}) = Omega0(nFreeDiag+1:nOmega0,nFreeDiag+1:nOmega0);
end

S_SE = zeros(RCDim,RCDim);

% Gradient of S w.r.t. elements of C
GradS = zeros(RCDim,RCDim,nFull);
for i1 = 1:RCDim
  GradC = zeros(RCDim,RCDim);
  GradC(i1,i1) = 1;
  GradS(:,:,i1) = GradC*C.'+C*GradC';
  GradC(i1,i1) = 0;
  for i2=1:i1-1
    GradC(i1,i2) = 1;
    index = RCDim + (i1-1)*(i1-2)/2+i2;
    GradS(:,:,index) = GradC*C.'+C*GradC';
    GradC(i1,i2)=0;
  end
end
    
for i1=1:RCDim
  
  % Standard error of S(i1,i1)
  S_SE(i1,i1) = sqrt(squeeze(GradS(i1,i1,:))'*Omega*squeeze(GradS(i1,i1,:)));
 
  for i2=1:i1-1
    % Standard error of S(i1,i2)
    S_SE(i1,i2) = sqrt(squeeze(GradS(i1,i2,:))'*Omega*squeeze(GradS(i1,i2,:)));
    S_SE(i2,i1) = S_SE(i1,i2);
  end
end
