function [l,dl,d2l]=like1(BetaFree,iFree,nFree,Beta,DeltaX,noptions,nobs, ...
                       OutDir)
%
% liked1: SIMPLE LOGIT  likelihood function
%
%
% [l,dl]=like1(BetaFree,iFree,nFree,Beta,DeltaX,DeltaX,noptions,nobs,OutDir)
%
% l	            =  (1 x 1) value of likelihood
% dl            =  (nFree x 1) gradient of likelihood
% BetaFree      =  (nFree x 1) vector of free parameters
% iFree         =  (nFree x 1) indexes of free parameters
% nFree         =  (1 x 1) length of iFree
% Beta          =  (nx    x 1) all parameters in x
% DeltaX        =  (noptions*nobs x k) data matrix (sparse)
% nobs          =  (1 x 1) number of observations
% noptions      =  (1 x 1) number of options
%
%
% All x variables are differenced
% DeltaX (noptions*nobs x k) product characteristics interacted with 
%                                  hh characteristics
%
% Revision history
% 2017MAR18   Cleaned version for QE.

SaveCurrentIteration(BetaFree,1,OutDir,1);
                                
Beta(iFree)=BetaFree;		% vector of all parameters
dv1=reshape(DeltaX*Beta,noptions,nobs);
vMax = max(dv1);
dv1=dv1-repmat(vMax,[noptions 1]);

if nargout==1
  t1=sum(exp(dv1)).';
  l = -sum(vMax) -sum(log(t1));
  
  l=-l;
  dl=0;
elseif nargout>1
  
  t1=exp(dv1);
  t2=sum(t1);
  l = -sum(vMax) - sum(log(t2));
  l=-l;
  
  t3 = reshape(t1./repmat(t2,[noptions 1]),noptions*nobs,1);  
  t4 = repmat(t3,[1 nFree]).*DeltaX(:,iFree);
  t5 = sum(reshape(t4,noptions,nobs*nFree),1);
  t5 = reshape(t5,nobs,nFree);
  d2l=zeros(nFree,nFree);
  if nargout==3
    t3=reshape(t3,[noptions nobs]);  
    for i1=1:nFree
      t6 = t3.*reshape(DeltaX(:,iFree(i1)),[noptions nobs]) ...
             .*reshape(DeltaX(:,iFree(i1)),[noptions nobs]);
      d2l(i1,i1) = sum(sum(t6,1))-sum(t5(:,i1).*t5(:,i1));
      for i2=i1+1:nFree
        t6 = t3.*reshape(DeltaX(:,iFree(i1)),[noptions nobs]) ...
               .*reshape(DeltaX(:,iFree(i2)),[noptions nobs]);
        d2l(i2,i1) = sum(sum(t6,1))-sum(t5(:,i1).*t5(:,i2));
        d2l(i1,i2) = d2l(i2,i1);
      end
    end
  end
  dl = full(sum(t5,1).');
end
if isnan(l) || any(isnan(dl))
    disp('l is nan');
    keyboard
end