function [HHPrice,BasePrice,X,Z] = ...
          ComputeBasePrice(PriceOption,SortedData,RawColumn,     ...
                           MarketShareHandle,X,Z,Market,         ...
                           basis,EstColumn,ZIndex,               ...
                           noptions,RCDim,nMarkets,nRegions,  ...
                           SortedProductCodeRaw,OutsideOptionColumn,   ...
                           PriceDataFile,MarketDefinition)
        
% Compute base price. Insert base price into X and Z
%    1) Option 1:  base price is average in market
%    2) Option 2:  base price is loaded from file
%
% Revision history
% 2017MAR18  Cleaned version for publication.

% Prices in data
RawPrice           = SortedData(:,RawColumn.Price);  % prices in data
HHGrossExpenditure = SortedData(:,RawColumn.Expenditure) + RawPrice;
HHPrice            = RawPrice;
HHNetExpenditure   = HHGrossExpenditure;

if PriceOption==1
  % Replace prices in price data with weighted average prices for each market
  HHShare=MarketShareHandle(X,Z);  
  BasePrice=zeros(noptions,nMarkets);
  for m=1:nMarkets
    i1 = Market==m;
    if any(Market)
      TempPrice = RawPrice(i1);
      TempShare = HHShare(i1);
      nTemp     = sum(i1)/noptions;
      BasePrice(:,m) =  sum(reshape(TempPrice.*TempShare,noptions,nTemp),2) ...
                     ./ sum(reshape(TempShare,noptions,nTemp),2);
      HHPrice(i1)          = repmat(BasePrice(:,m),[nTemp 1]);
      HHNetExpenditure(i1) = HHGrossExpenditure(i1) - HHPrice(i1);
    end
  end
  
  index = RawPrice==0;
  if any(HHPrice(index)~=0)
    disp('HHPrice is zero but NewHHPrice is not zero.')
    keyboard
  end
  
  iNonZero = RawPrice~=0;
  [X,Z]=UpdatePriceTerms(HHNetExpenditure,X,Z,basis,EstColumn, ...
                         ZIndex,iNonZero,RCDim);
  X.Price = HHPrice;                    
elseif PriceOption==2
    
  % load PriceData from  PriceDataFile
  PriceData=importdata(PriceDataFile{MarketDefinition},',',1);

  if MarketDefinition==4
    % reorganize data before copying to BasePrice  
    % find column index of each variable in raw data
    iRegion = strcmp('region',PriceData.textdata);
    iMonth  = strcmp('month',PriceData.textdata);
    iPrice  = strcmp('p_mean',PriceData.textdata);
  
    % reorganise data so that
    %    col 1     product code
    %    col 2     market    (month, region)
    %    col 3     price
    %    col 4     region
    %    col 5     month
    PriceData.data = [PriceData.data(:,1), ...
                      nRegions*(PriceData.data(:,iMonth)-1) ...
                         + PriceData.data(:,iRegion),       ...
                      PriceData.data(:,iPrice),             ...
                      PriceData.data(:,iRegion),   ...
                      PriceData.data(:,iMonth)];
    % adjust column labels
    temp=cell(5,1);
    temp{1} = PriceData.textdata{1};
    temp{2} = 'market';
    temp{3} = PriceData.textdata{4};
    temp{4} = PriceData.textdata{2};
    temp{5} = PriceData.textdata{3};
    PriceData.textdata = temp;
    PriceData.colheaders = temp;
  end % if MarketDefinition == 4
  
  % Copy data from PriceData.data to BasePrice
  % Then copy BasePrice to NewHHPrice
  BasePrice=zeros(noptions,nMarkets);
  for m=1:nMarkets
    i1 = Market==m;
    nTemp=sum(i1)/noptions;
    for j=1:noptions
      if j~=OutsideOptionColumn  
          
        % assumptions
        %    PriceData.data(:,1) = product code
        %    PriceData.data(:,2) = market id number
        %    PriceData.data(:,3) = market price
        index = PriceData.data(:,1)==SortedProductCodeRaw(j) & ...
                PriceData.data(:,2)==m;
        BasePrice(j,m) = PriceData.data(index,3);     
      end
    end   
    HHPrice(i1) = repmat(BasePrice(:,m),[nTemp 1]);
    HHNetExpenditure(i1) = HHGrossExpenditure(i1) - HHPrice(i1);
  end 

  index = RawPrice==0;
  if any(HHPrice(index)~=0)
    disp('HHPrice is zero but NewHHPrice is not zero.')
    keyboard
  end

  iNonZero = RawPrice~=0;
  [X,Z]=UpdatePriceTerms(HHNetExpenditure,X,Z,EstColumn, ...
                         ZIndex,iNonZero);
  X.Price = HHPrice;
elseif PriceOption==3
    
  % load PriceData from  HHTaxResults
  %  BasePrice
  %  NewHHPrice
  load(PriceDataFile);
  HHNetExpenditure = HHGrossExpenditure - NewHHPrice;
  iNonZero = RawPrice~=0;
  
  [X,Z]=UpdatePriceTerms(HHNetExpenditure,X,Z,basis,EstColumn, ...
                         ZIndex,iNonZero,RCDim);
  HHPrice = NewHHPrice;
  X.Price = HHPrice;
end  % If PriceOption==1