function  [NashExitFlag,NashOutput,TotalTime] = ComputeEquilibrium( ...
    HHWeights,X,Z,Market,HHProductCode,                             ...    
    BasePrice,BaseCost,Sats,AllFirmsProducts,AllCompetitorProducts, ...
    nMarkets,noptions,nHH,RCDim,RCRank,nFirms,Tax,                  ...
    IncludeOutsideOption,OutsideOptionColumn,                       ...
    LogNormalFlag,LogNormalIndex,basis,EstColumn,ZIndex,            ...
    xFree2,iFree2,beta2,CDiag,COffDiag,Nodes,Weights,nQuadAll,      ...
    Subset,pid,TempDirList,OwnershipFlag,MultipleEquilibriumFlag,taskID)

% Revision history
% 2017MAR19  Cleaned version for publication.
TestSubsetFlag=0;
if TestSubsetFlag==1
  % Test computations on subsample.
  nHH = 5000;
  HHWeights           = HHWeights(:,1:nHH);
  TestIndex           = (1:nHH*noptions)';
  X.X                 = X.X(TestIndex,:);
  X.GradX             = X.GradX(TestIndex,:);
  X.HessX             = X.HessX(TestIndex,:);
  X.xInteraction      = X.xInteraction(TestIndex,:);
  X.Price             = X.Price(TestIndex);
  X.GrossExpenditure  = X.GrossExpenditure(TestIndex);

  Z.Z           = Z.Z(TestIndex,:);
  Z.GradZ       = Z.GradZ(TestIndex,:);
  Z.HessZ       = Z.HessZ(TestIndex,:);
  Market        = Market(TestIndex);
  HHProductCode = HHProductCode(TestIndex);
end

if exist('MultipleEquilibriumFlag','var')==0
  MultipleEquilibriumFlag=0;
end
%% Calculate Nash Equilibrium:   single product firms
%
% Set up matrices to store results
NashProducerPrice=zeros(noptions,nMarkets);   % NashProducerPrice contains 
                                              % the Nash Equilibrium producer 
                                              % prices, one vector for each market
HHNashConsumerPrice=zeros(noptions*nHH,1);    % vector of Nash Consumer prices at (hh,product) level

Residual=zeros(noptions,nMarkets);    % Residual contains the vector of residuals 
                                      % from the equilibrium equation
                                      % one for each market
NashExitFlag=zeros(nMarkets,1);       % ExitFlags from nonlinear equation solver.
                                      % One for each market
NashOutput=cell(nMarkets,1);          % Other output of nonlinear equation solver.
                                      % One for each market

% Options for Nonlinear Equation Solver
FsolveOptions=optimset('DerivativeCheck','off', ...
                       'Display','off',        ...
                       'Jacobian','on',        ...
                       'MaxFunEvals', 40000,      ...
                       'MaxIter',100,           ...
                       'TolFun', [],          ...
                       'TolX',   []);
OptimFlag=2;
if OptimFlag==2
  FsolveOptions = optimset(FsolveOptions,'Algorithm','levenberg-marquardt');
elseif OptimFlag==3
  FsolveOptions = optimset(FsolveOptions,'Algorithm','trust-region-reflective');
end
% Compute equilibrium price vector, one for each (month,region)
TotalTime=0;


%% Maximum number of households to evaluate in one block
MaxN=10;
tic

TestEquilibrium=2;    % 1 test computation of jacobian of R
                      % 2 use fsolve on subset of prices

% Subset{pid} =  set of markets to be computed by current pid                      
for m=Subset{pid}
  % Rows in data matrix corresponding to current HH's
  iCurrent = Market==m;
  nTemp = sum(iCurrent)/noptions;
  
  if nTemp>0
    % This step selects the rows from Z that correspond to the current HH.  
    %    CurrentZ contains the rows of Z corresponding to the current HH
    CurrentZ.Z = Z.Z(iCurrent,:);
    CurrentZ.GradZ = Z.GradZ(iCurrent,:);
    CurrentZ.HessZ = Z.HessZ(iCurrent,:);
     
    TempX.X                = X.X(iCurrent,:);
    TempX.GradX            = X.GradX(iCurrent,:);
    TempX.HessX            = X.HessX(iCurrent,:);
    TempX.Price            = X.Price(iCurrent);
    TempX.GrossExpenditure = X.GrossExpenditure(iCurrent);
    TempX.xInteraction     = X.xInteraction(iCurrent,:);
    iNonZero    = (TempX.Price~=0);
    TempWeights = HHWeights(reshape(iCurrent,noptions,nHH));
    TempWeights = reshape(TempWeights,noptions,nTemp);
    
    if nQuadAll < size(Nodes,1)
      nHH_data = size(Nodes,1)/nQuadAll;
      nT       = nHH/nHH_data;
      t1 = kron((1:nHH_data)',ones(nT*noptions,1));
      t1 = reshape(t1(iCurrent),[noptions sum(iCurrent)/noptions]);
      TempNodes = reshape(Nodes,[nHH_data nQuadAll RCRank]);
      TempNodes = TempNodes(t1(1,:)',:,:);
      TempNodes = reshape(TempNodes,[nQuadAll*sum(iCurrent)/noptions RCRank]);
    else
      TempNodes = Nodes;
    end

    InitialPrice=BasePrice(:,m);
    if IncludeOutsideOption==0
      iPrice=(1:noptions)';
    elseif IncludeOutsideOption==1
      iPrice=(1:noptions)';
      iPrice=iPrice(iPrice~=OutsideOptionColumn);
    end
    FreePrice = InitialPrice(iPrice);

    if TestEquilibrium==1
      exitflag = ...
      TestEquilibrium2_wrapper(FreePrice,iPrice,InitialPrice,  ...
                               BaseCost(:,m),Tax,Sats,         ...
                               TempWeights, ...
                               TempX,CurrentZ,iNonZero,basis, ...
                               noptions,nTemp,RCDim,RCRank,    ...
                               LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                               xFree2,iFree2,beta2,CDiag,COffDiag,nFirms,    ...
                               AllFirmsProducts,AllCompetitorProducts,    ...
                               HHProductCode(iCurrent),TempNodes,Weights,     ...
                               nQuadAll,MaxN);

      [R0,J0,J1]=TestEquilibrium2(InitialPrice,BaseCost(:,m),Tax,Sats,     ...
                                  iPrice,TempWeights, ...
                                  TempX,CurrentZ,iNonZero,basis,            ...
                                  noptions,nTemp,RCDim,RCRank, ...
                                  LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                                  xFree2,iFree2,beta2,CDiag,COffDiag,nFirms,AllFirmsProducts,  ...
                                  AllCompetitorProducts,                   ...
                                  HHProductCode(iCurrent),TempNodes,           ...
                                  Weights,nQuadAll,MaxN);
    elseif TestEquilibrium==2

      ResidualFunc = ...
          @(Price)Equilibrium2_wrapper(Price,iPrice,InitialPrice,  ...
                                       BaseCost(:,m),Tax,Sats,     ...
                                       TempWeights, ...
                                       TempX,CurrentZ,iNonZero,basis,    ...
                                       noptions,nTemp,RCDim,RCRank,      ...
                                       LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                                       xFree2,iFree2,beta2,CDiag,COffDiag,nFirms,     ...
                                       AllFirmsProducts,            ...
                                       AllCompetitorProducts,       ...
                                       HHProductCode(iCurrent),     ...
                                       TempNodes,Weights,nQuadAll,MaxN);
      if MultipleEquilibriumFlag==1
        % search for multiple equilibria
        % perturb starting price by random vector lambda
        nTest = 500;
        J = size(FreePrice,1);
        s0 = rng;
        rng('default');
        lambda = 0.1 + (1.2-0.1)*rand(J,nTest);
        StartPrice = zeros(J,nTest);
        FinalPrice = zeros(J,nTest);
        for i1=1:nTest
           StartPrice(:,i1) = FreePrice.*lambda(:,i1);
           FinalPrice(:,i1)= fsolve(ResidualFunc,StartPrice(:,i1),FsolveOptions);
        end
        rng(s0);
      end
      [P1,R1,Flag1,Out1]= fsolve(ResidualFunc,FreePrice,FsolveOptions);
       NashProducerPrice(iPrice,m) = P1;       
       Residual(iPrice,m)          = R1;
       NashExitFlag(m)             = Flag1;
       NashOutput{m}               = Out1;
       
       % Save results of current market to file
       % save [P1, R1]
       CurrentOutFile = fullfile(TempDirList{pid}, ...
           ['Equilibrium_', ...
            int2str(Tax.Type), '_', ...
            int2str(OwnershipFlag),'_', ...
            int2str(m),'.mat']);
       if MultipleEquilibriumFlag==0
         save(CurrentOutFile,'-v7.3','P1','R1');
       else
           save(CurrentOutFile,'-v7.3','P1','R1','StartPrice','FinalPrice');
       end
    end
    
    if nTemp==1
      if Tax.Type==1
        HHNashConsumerPrice(iCurrent)=NashProducerPrice(:,m)+Tax.tax*Sats;
      elseif Tax.Type==2
        HHNashConsumerPrice(iCurrent)=NashProducerPrice(:,m).*(1+Tax.tau*Sats);
      elseif Tax.Type==3
        HHNashConsumerPrice(iCurrent)=NashProducerPrice(:,m);
      end
    elseif nTemp>1
      if Tax.Type==1
        HHNashConsumerPrice(iCurrent)=repmat(NashProducerPrice(:,m)+Tax.tax*Sats,[nTemp 1]);
      elseif Tax.Type==2
        HHNashConsumerPrice(iCurrent)=repmat(NashProducerPrice(:,m).*(1+Tax.tau*Sats),[nTemp 1]);
      elseif Tax.Type==3
        HHNashConsumerPrice(iCurrent)=repmat(NashProducerPrice(:,m),[nTemp 1]);
      end
    end
  end % if nTemp>0
  CurrentTime=toc/3600;
  TotalTime=TotalTime+CurrentTime;
  format short e
  disp('m nMarkets CurrentTime TotalTime (hours)');
  disp([m nMarkets CurrentTime TotalTime])
  % file location depends on current pid
  if exist('taskID','var')==0
    taskID=0;
  end
  TempName = fullfile(TempDirList{pid}, ...
                      ['TempNashResults_',int2str(Tax.Type),'_',int2str(taskID),'.mat']);  
  save(TempName,'-v7.3');
end  % for m=1:nMarkets

disp(['Total time required to compute ALL equilibria: ',num2str(TotalTime)])
