function [F,D1F,p,SOC] = ComputeProfit(j,jFirm,np,nHH,BasePrice,cost, ...
                                     X,Z,HHWeights, ...
                                     UpdatePriceHandle,MarketShare2Handle)
% Compute profits of firm that owns products jFirm as function of price(j).
% Also compute derivative of profits and eigenvalues of hessian of profit.
%
% Revision history
% 06MAY2014 LN update to work with expenditure.
% 22OCT2013 LN created subroutine

p=linspace(0.5*BasePrice(j),1.5*BasePrice(j),np)';

F=zeros(np,1);
D1F = zeros(np,1);

if nargout>2
  % GradS  (J x J x nHH)     GradS(i,j,:)    = deriv. of S(j) w.r.t. p(i)
  % S_Hess (J x J x J x nHH) S_Hess(i,j,k,:) = deriv. of S(k) w.r.t. p(i) 
  %                                            then p(j)
  tic;
  [~,GradS,~,S_Hess]=MarketShare2Handle(X,Z);
  t1=toc/60;
  display(['Market Share time: ',num2str(t1),' minutes.']);
  nFirm = size(jFirm,1);
  Hess= zeros(nFirm,nFirm);
  margin = BasePrice(jFirm)-cost;
  for i1=1:nFirm
    Hess(i1,i1) = 2*(HHWeights(1,:)*squeeze(GradS(jFirm(i1),jFirm(i1),:))) ...
                  + margin.'* ...
                  (reshape(S_Hess(jFirm(i1),jFirm(i1),jFirm,:),[nFirm nHH])*HHWeights(1,:).');
    for i2=1:i1-1
      Hess(i2,i1) = HHWeights(1,:) ...
          *squeeze(GradS(jFirm(i1),jFirm(i2),:)+GradS(jFirm(i2),jFirm(i1),:)) ...
          + margin.'* (reshape(S_Hess(jFirm(i1),jFirm(i2),jFirm,:),[nFirm nHH])*HHWeights(1,:).');
      Hess(i1,i2) = Hess(i2,i1);
    end
  end
  SOC = eig(Hess);
end

NewPrice = BasePrice;
for i1=1:np
  NewPrice(j) = p(i1);
  NewExpenditure = X.GrossExpenditure - kron(ones(nHH,1),NewPrice);
  [X,Z]=UpdatePriceHandle(NewExpenditure);
  [S,GradS]=MarketShare2Handle(X,Z);
  margin = NewPrice(jFirm)-cost;
  F(i1) = margin.'*(S(jFirm,:)*HHWeights(1,:)'); 
  D1F(i1) = S(j,:)*HHWeights(1,:)'  ...
            + margin.'*(reshape(GradS(j,jFirm,:),[nFirm nHH])*HHWeights(1,:)');
  display([j i1]) 
end