function tau = ComputeTax2HitTarget(ParameterFile,Tax,OwnershipFlag,BootstrapDataFile)

% Compute compute tax to hit target
% 
% Revision history:
% 2017MAR19 Cleaned version for publication.



%--------------------------------------------------------------------------
%% Parameters
%--------------------------------------------------------------------------
eval(ParameterFile);

if OwnershipFlag==1 && Tax.Type<3 && Tax.NewTaxFlag==1
  % if NewTaxFlag==1, compute tax for new ownership structure
  % use prices from output of (OwnershipFlag==1 && Tax.Type==3)
  % use costs from datafile
  PriceOption=3;  
  PriceDataFile = Tax.PriceDataFile;
end

if nargin>=4
  BaseTaxDataFile = BootstrapDataFile;
end

%--------------------------------------------------------------------------
%% Load and extract data
%--------------------------------------------------------------------------
%   Ownership Matrix
%   ProductCodeRaw
%   SortedData
%   (xFree2,iFree2,beta2,C)
%   nFirms,AllFirmsProducts,NewHHProductCode
%   Nodes,Weights,nQuadAll
%
% BaseTaxDataFile is created by AnalyseResults
aa=clock;
disp(['Loading ',BaseTaxDataFile,'. Current time: ', ...
      int2str(aa(4)),':',int2str(aa(5))]);
tic
load(BaseTaxDataFile);
%if exist('basis.ZeroPriceFlag','var')==0
%  basis.ZeroPriceFlag=1;
%end
[X,Z]=NewData(SortedData,SortedData(:,RawColumn.FixedEffect), ...
              RawColumn,basis,ZIndex, ...
              nHH,noptions);
X.X=full(X.X);
aa=clock;
t1=toc/60;
%disp(['Current time: ',int2str(aa(4)),':', ...
%      int2str(aa(5)),'. Data load time: ',int2str(t1)]);

% Variables used to gross up from data to actual market shares
if ~isempty(RawColumn.SampleWeight)
  HHWeights = reshape(SortedData(:,RawColumn.SampleWeight),noptions,nHH);
else
  HHWeights = ones(noptions,nHH);
end
RawScale = sum(HHWeights(1,:));
NewScale = nHH;
HHWeights = NewScale*HHWeights/RawScale;

% Data on saturated fat content  (first noptions rows only)
Sats=SortedData(1:noptions,RawColumn.Sats);

%--------------------------------------------------------------------------
%% Define market.
% In data, 
%     price = (actual price)               when Choice==1
%     price = (avg. price in region,month) when Choice==0
%
%--------------------------------------------------------------------------
[Market,nHH] = DefineMarket(SortedData,RawColumn,MarketDefinition, ...
                            noptions,nMonths,nRegions);

%--------------------------------------------------------------------------
%% Set baseline price  
%  PriceOption == 1:  use weighted average of prices in data
%  PriceOption == 2:  use data from PriceDataFile
%--------------------------------------------------------------------------
MarketShareHandle = ...
      @(X,Z)MarketShare(X,Z, ...
                        xFree2,iFree2,beta2,CDiag,COffDiag, ...
                        LogNormalFlag,LogNormalIndex,       ...
                        EstColumn,ZIndex,        ...
                        noptions,nHH,RCDim,RCRank, ...
                        nFirms,AllFirmsProducts, ...
                        NewHHProductCode, ...
                        Nodes,Weights,nQuadAll);

[HHPrice,BasePrice,X,Z] = ...
    ComputeBasePrice(PriceOption,SortedData,RawColumn, ...
                     MarketShareHandle,X,Z,Market,      ...
                     basis,EstColumn,ZIndex,            ...
                     noptions,RCDim,nMarkets,nRegions, ...
                     SortedProductCodeRaw,OutsideOptionColumn, ...
                     PriceDataFile,MarketDefinition);

%--------------------------------------------------------------------------
%% Calculate BASELINE shares
%--------------------------------------------------------------------------
HHShare = MarketShareHandle(X,Z);

%--------------------------------------------------------------------------
%% New ownership matrix
% OwnershipFlag=0    True ownership
% OwnershipFlag=1    New ownership structure
%
% Ownership structure defined by:
%    AllFirmsProducts
%    AllCompetitorProducts
%    SortedHHFirmCode
%    SortedFirmCode
%    nFirms
%  
if OwnershipFlag==1                 
  % Create new ownership structure in which each product is a single firm
  [nFirms,AllFirmsProducts] ...
      = CreateNewOwnership(noptions);
end

%--------------------------------------------------------------------------
%% Calculate prices and shares with tax:    NO FIRM RESPONSE
%--------------------------------------------------------------------------
target = 0.2;
TaxShareHandle = @(Tax)ComputeTaxShare(Tax, ...
                          xFree2,iFree2,beta2,CDiag,COffDiag,       ... 
                          X,Z,LogNormalFlag,LogNormalIndex,         ...
                          basis,EstColumn,ZIndex,                   ...
                          noptions,nHH,RCDim,RCRank,                ...
                          nFirms,AllFirmsProducts,NewHHProductCode, ...
                          Nodes,Weights,nQuadAll,                   ...
                          BasePrice,HHPrice,Sats,nMarkets);
PreTaxSats  = (Sats'*HHShare)*HHWeights(1,:)';
FuncHandle = @(tau,fail)SatTargetResidual(tau,fail, ...
               Tax,TaxShareHandle,target, ...
               Sats,HHWeights,PreTaxSats);

% find tax such that:  reduction - target = 0
if Tax.Type==1
  LoTau = 0.1;
  HiTau = 0.2;
else
  LoTau = 0;
  HiTau = 0.1;
end
tau=zbrent2(FuncHandle,LoTau,HiTau);                              
