function [BaseShare,TaxShare,NashShare]=ExtractProductLevelResults( ...
          Market,nMarkets,noptions, ...
          HHShare,HHTaxShare,HHNashShare,HHWeights)
% Create product level data sets for market shares from HH level data
%
% Revision history
% 2017MAR19  Cleaned version for publication.

BaseShare = zeros(noptions,nMarkets);
TaxShare  = BaseShare;
NashShare = BaseShare;

for m=1:nMarkets
  disp(m);    
  % Rows in data matrix corresponding to current HH's
  iCurrent    = (Market==m);
  nTemp = sum(iCurrent)/noptions;
  
  if nTemp>0
    % For each market m compute initial price guess and cost
    TempShare        = HHShare(iCurrent);
    TempTaxShare     = HHTaxShare(iCurrent);
    TempNashShare    = HHNashShare(iCurrent);
    TempWeight       = HHWeights(iCurrent);
    
    if nTemp>1
      TempWeight     = reshape(TempWeight,noptions,nTemp);
      TempShare      = reshape(TempShare,noptions,nTemp);
      TempTaxShare   = reshape(TempTaxShare,noptions,nTemp);
      TempNashShare  = reshape(TempNashShare,noptions,nTemp);
  
      BaseShare(:,m) = sum(TempShare.*TempWeight,2);
      TaxShare(:,m)  = sum(TempTaxShare.*TempWeight,2);
      NashShare(:,m) = sum(TempNashShare.*TempWeight,2);
      
    elseif nTemp==1
      BaseShare(:,m) = TempShare;
      TaxShare(:,m)  = TempTaxShare;
      NashShare(:,m) = TempNashShare;
      
    end
  end
end  % for m=1:nMarkets