function Tax = SetTaxParameters(Tax,OwnershipFlag,OutDir,noptions)
%
% Set values for all tax parameters.
%
% Revision history
% 2017MAR19 Cleaned version for publication.

% Tax parameters
%   TaxType:        1 Excise tax
%                   2 Ad Valorem tax
%                   3 No tax
%   OwnershipFlag:  0 Baseline ownership structure
%                   1 Single product firm structure

Tax.String     = cell(3,1);
Tax.String{1}  = 'BaseTax';
Tax.String{2}  = 'AV';
Tax.String{3}  = 'NoTax';

% Magnitude of tax
TestTaxFlag = 0;
if TestTaxFlag==0
  Tax.BaseTax = 100*0.001;
elseif TestTaxFlag==1
  Tax.BaseTax = 0;
end
Tax.tax     = Tax.BaseTax;

Tax.BaseTax_ProductLevelResultsRawFile = fullfile(OutDir, ...
                                                  [Tax.String{1}, ...
                                                   '_ProductTaxResults.raw']);

if Tax.Type==2
  Tax.tau = Compute_AV_Tau(Tax.BaseTax_ProductLevelResultsRawFile,Tax.BaseTax, ...
                           noptions); 
end

if OwnershipFlag==0
  % tax results file names: base ownership structure 
  Tax.TaxResultsMatFile             = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_TaxResults.mat']);
  Tax.HHLevelTaxResultsRawFile      = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_HHTaxResults.raw']);
  Tax.ProductLevelTaxResultsRawFile = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_ProductTaxResults.raw']);
  Tax.WelfareResultsFile            = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_WelfareResults.raw']);
elseif OwnershipFlag==1
  % tax results file names: single product firms ownership structure
  Tax.TaxResultsMatFile             = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_TaxResults_Single.mat']);
  Tax.HHLevelTaxResultsRawFile      = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_HHTaxResults_Single.raw']);
  Tax.ProductLevelTaxResultsRawFile = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_ProductTaxResults_Single.raw']);
  Tax.WelfareResultsFile            = fullfile(OutDir, ...
                                               [Tax.String{Tax.Type}, ...
                                                '_WelfareResults_Single.raw']);
  Tax.PriceDataFile                 = fullfile(OutDir,'PriceData_Single.mat');
end