function [X,Z]=UpdatePriceTerms(NewExpenditure,X,Z,basis,EstColumn,ZIndex, ...
                                 iNonZero,RCDim)
% Update (X,Z) by replacing Price with NewExpenditure
%
% Revision history
% 2017MAR18  Cleaned version for publication.

if basis.flag~=4
  iZeroPrice = (~iNonZero);
  [f,df,d2f]=ComputeBasisFunctions(NewExpenditure,basis);
  f=f';
  df=df';
  d2f = d2f';
  if basis.ZeroPriceFlag==1
    f(iZeroPrice,:)   = 0;
    df(iZeroPrice,:)  = 0;
    d2f(iZeroPrice,:) = 0;
  end
  [nTotal,nx] = size(X.xInteraction);

  % X.X = [f(p).*x2 x1 BrandDummies ]
  x1 = zeros(nTotal,(nx+1)*basis.nf);
  X.GradX = x1;
  X.HessX = x1;

  for i1=0:nx
  for i2=1:basis.nf
      index = i1*basis.nf+i2;
    if i1==0
      x1(:,index)      = f(:,i2);
      X.GradX(:,index) = df(:,i2);
      X.HessX(:,index) = d2f(:,i2);
    else
      x1(:,index)      = f(:,i2).*X.xInteraction(:,i1);
      X.GradX(:,index) = df(:,i2).*X.xInteraction(:,i1);
      X.HessX(:,index) = d2f(:,i2).*X.xInteraction(:,i1);
    end
  end
  end
  X.X(:,EstColumn.Expenditure) = x1;
  X.X=sparse(X.X);
  X.GradX = sparse(X.GradX);
  X.HessX = sparse(X.HessX);

  % update Z
  for i1= ZIndex.iP'
    Z.Z(:,i1)     = f(:,i1);  
    Z.GradZ(:,i1) = df(:,i1);
    Z.HessZ(:,i1) = d2f(:,i1);
  end
elseif basis.flag==4
  X.X(:,EstColumn.Expenditure) = ...
      X.GradX.*repmat(NewExpenditure,[1 size(EstColumn.Expenditure,1)]);
  % X.GradX unchanged
  % X.HessX unchanged
  for i1=1:RCDim
    if any(i1==ZIndex.iP)
      Z.Z(:,i1) = Z.GradZ(:,i1).*NewExpenditure;
    end
    % Z.GradZ unchanged
    % Z.HessZ unchanged
  end   % for i1=1:RCDim
end     % if basis.flag~=4  
