function HHGradS1=TestMarketShare2(MarketShareHandle,rows,noptions,nobs, ...
                                   HHGradS,X,Z,basis,EstColumn,ZIndex,   ...
                                   RCDim)
% Compute numerical gradient of MarketShare for each row in rows.
% rows    = (n x 1)  indexes of rows to compute in HHGradS
%
% Revision history
% 06MYA2014 LN  update to work with expenditure.
% 21OCT2013 LN  new version of Z.Z
% 28may2013 LN  clean up and make to work with basis.
% 21feb2012 LN  clean up and add 2 sided differencing
% 15feb2012 LN  add HessX
% 13feb2012 LN  replace call to MarketShare with call to MarketShareHandle
% 23jan2012 LN  edit to compute gradient correctly in case where utility is
%               a nonlinear function of price.
% 20jan2012 LN  replace PriceIndex1 and PriceInteractionIndex1 with
%               EstColumn.Price and EstColumn.Price_X to facilitate
%               computation of gradient when utility is nonlinear function
%               of price
HHGradS1=zeros(noptions,noptions,nobs);

% columns of X containing x*p
iNonZero = X.Price~=0;

J=length(rows);

HHExpenditure0 = reshape(X.GrossExpenditure-X.Price,noptions,nobs);
for j=1:J
  HHExpenditure1=HHExpenditure0;
  HHExpenditure1(rows(j),:)=HHExpenditure0(rows(j),:)+1e-4;
  [X,Z]=UpdatePriceTerms(HHExpenditure1(:),X,Z,basis,EstColumn,ZIndex, ...
                         iNonZero,RCDim);

  HHShare1 = MarketShareHandle(X,Z);
  
  HHExpenditure2 = HHExpenditure0;
  HHExpenditure2(rows(j),:) = 2*HHExpenditure0(rows(j),:) - HHExpenditure1(rows(j),:);
  [X,Z]=UpdatePriceTerms(HHExpenditure2(:),X,Z,basis,EstColumn,ZIndex, ...
                         iNonZero,RCDim);
  HHShare2 = MarketShareHandle(X,Z);
                 
  temp=(HHShare1-HHShare2)' ...
      ./repmat((HHExpenditure1(rows(j),:)-HHExpenditure2(rows(j),:))', ...
               [1 noptions]);
  HHGradS1(rows(j),:,:)=temp';
  disp(rows(j))
end

% In HHGradS, derivative of firm j share w.r.t. prices of other firms is
% set equal to zero.

HHGradS1(HHGradS==0) = 0;

aa=HHGradS(rows,:,:)-HHGradS1(rows,:,:);
aa=aa(:);
result=max(abs(aa));
disp(result)
