function e = TestNewData(SortedData,X,Z,NewDataHandle, ...
                         RawColumn,basis,ZIndex)
% Revision history
% 2017MAR18  Cleaned version for publication.
e = zeros(3+2*length(ZIndex.iP),1);
% Test NewData
% 1) Test that X.GrossExpenditure - X.Price = SortedData(:,RawColumn.Expenditure);
% 2) Test that dX.X/dExpenditure = X.GradX
% 3) test that d2X.X/dExpenditure^2 = X.HessX
% 4) test Z

% 1) Test that X.Expenditure = SortedData(:,RawColumn.Expenditure);
e(1) = max(abs(X.GrossExpenditure-X.Price ...
               - SortedData(:,RawColumn.Expenditure)));

% 2) Test that dX.X/dExpenditure = X.GradX
% 3) test that d2X.X/dExpenditure^2 = X.HessX
h=1e-6;
expenditure = SortedData(:,RawColumn.Expenditure);
iNonZero = true(size(expenditure)); %SortedData(:,RawColumn.Price)>0;

expenditure1 = expenditure;
expenditure2 = expenditure;
expenditure1(iNonZero) = expenditure(iNonZero)+h;
expenditure2(iNonZero) = 2*expenditure(iNonZero)-expenditure1(iNonZero);

SortedData(iNonZero,RawColumn.Expenditure) = expenditure1(iNonZero);
[X1,Z1] = NewDataHandle(SortedData);
SortedData(iNonZero,RawColumn.Expenditure) = expenditure2(iNonZero);
[X2,Z2] = NewDataHandle(SortedData);

ngrad = basis.nf*(size(RawColumn.Interaction,1)+1);
Grad1 = zeros(size(X.GradX));
Grad1(iNonZero,:) = (X1.X(iNonZero,1:ngrad)-X2.X(iNonZero,1:ngrad))./ ...
                     repmat(expenditure1(iNonZero)-expenditure2(iNonZero),[1 ngrad]);
e(2) = max(abs(Grad1(:)-X.GradX(:)));

Hess1 = zeros(size(X.HessX));
Hess1(iNonZero,:) = (X1.GradX(iNonZero,:)-X2.GradX(iNonZero,:)) ./ ...
                    repmat(expenditure1(iNonZero)-expenditure2(iNonZero),[1 ngrad]);
e(3) = max(abs(Hess1(:)-X.HessX(:)));                

% 4) test Z.GradZ(:,j) = dZ.Z(:,j) / dp
for i1=1:length(ZIndex.iP)
  TempZ1 = Z1.Z(:,i1);
  TempZ2 = Z2.Z(:,i1);
  GradZ1 = zeros(size(expenditure));
  GradZ1(iNonZero) = (TempZ1(iNonZero)-TempZ2(iNonZero))./ ...
       (expenditure1(iNonZero)-expenditure2(iNonZero));
  e(3+i1) = max(abs(GradZ1 - Z.GradZ(:,i1)));
end

% 5) test Z.HessZ(:,j) = d2Z.Z(:,j) / dp^2
for i1=1:length(ZIndex.iP)
  TempZ1 = Z1.GradZ(:,i1);
  TempZ2 = Z2.GradZ(:,i1);
  HessZ1 = zeros(size(expenditure));
  HessZ1(iNonZero) = (TempZ1(iNonZero,1)-TempZ2(iNonZero,1))./ ...
       (expenditure1(iNonZero)-expenditure2(iNonZero));
  e(3+length(ZIndex.iP)+i1) = max(abs(HessZ1-Z.HessZ(:,i1)));
end