function [xoptimal,ObjValue,exitflag,output,lambda,grad,hess] = ...
          CallNAG(LikeFunc,x0,A,B,Aeq,Beq,lower,upper, ...
                  NonLinConFunc,CL,CU,options)

% Inititalize e04wd
[iw,rw,exitflag] = e04wc;

% set optimization options
exitflag = nag_issue_warnings(true);  % if error, create flag but no crash
[iw,rw,exitflag] = SetNAGOptions(iw,rw,options);

n     = int64(length(x0));
nclin = int64(size(A,1)+size(Aeq,1));
ncnln = int64(length(CL));

if nclin==0
  A=zeros(1,1);
else 
  A = [Aeq; ...
       A];
end

% lower bounds
%  1) lower bounds on x
%  2) linear equality
%  3) linear inequality
%  4) non-linear
BL = [lower; ...
      -Beq;     ...
      -inf*ones(length(B),1);       ...
      CL];
BU = [upper; ...
      Beq;   ...
      B;     ...
      CU];
  
if isempty(NonLinConFunc)
  confun = 'e04wdp';
else
  confun = 'NAG_ConFun';
end

istate = int64(zeros(n+nclin+ncnln,1));
ccon   = zeros(max(1,ncnln),1);
cjac   = zeros(max(1,ncnln),n);
lambda = zeros(n+nclin+ncnln,1);
hess   = eye(n);

user.LikeFunc = LikeFunc;
user.NonLinConFunc = NonLinConFunc;
user.GradConstr = options.GradConstr;
    
% Requires license for NAG matlab toolbox.
[majits,istate,ccon,cjac,lambda,ObjValue,grad,hess,xoptimal,iw,rw,user,exitflag] = ...
  e04wd(A,BL,BU,confun,'NAGLike',istate,ccon,cjac,lambda,hess,x0,iw,rw,  ...
        'n',n,'nclin',nclin,'ncnln',ncnln,'user',user);
    
output.majits = majits;
output.istate = istate;
output.ccon   = ccon;
output.cjac   = cjac;
