function [s,d,crit]=ComputeWaldTest(b,sig_b,R,q)
% Compute wald test statistic for test R*b = q
% 
% s     = (1 x 1)  value of test statistic
% d     = (1 x 1)  degrees of freedom
% crit  = (1 x 1)  95% critical value for chi2 with d degrees of freedom
% b     = (k x 1)  vector of parameters
% sig_b = (k x k)  covariance matrix of b
% R     = (n x k)  linear restrictions:   R*b = q
% q     = (n x 1)  
t1=R*b-q;
d = size(R,1);
sig = R*sig_b*R';

s = t1'*(sig\t1);

crit = chi2inv(0.95,d);


