function [xFree,beta,StandardErrors,BIC] = ...
    PrintEstimationResults_Model1(xoptimal,LikeValue,grad,Hess,timings,TimeFactor, ...
                                  iFree,beta,nFree,nHH,OutFile,DeltaXLabels)

xFree=xoptimal;
beta(iFree.beta) = xFree;

StandardErrors=full(sqrt(diag(inv(Hess))));
BIC = 2*LikeValue+nFree*log(nHH);

fid=fopen(OutFile,'w');
LabelWidth=30;
for i1=1:size(beta,1)
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],DeltaXLabels{i1});
  % Print parameter estimate and Standard error for free parms.  
  if any(iFree.beta==i1)
    i2=find(iFree.beta==i1);
    fprintf(fid,'%-5d %25.16e %25.16e %25.16e', ...
         [i1 beta(i1) StandardErrors(i2) beta(i1)./StandardErrors(i2)]);
  else
  % Print parameter value and zero for fixed parameters.
    fprintf(fid,'%-5d %25.16e %25.16e',[i1 beta(i1) 0.0]);
  end

  fprintf(fid,'\n');
end
    
% Value of likelihood
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Likelihood');
fprintf(fid,'%25.16e',LikeValue);
fprintf(fid,'\n');

% max value of gradient of likelihood
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Max. Grad.');
fprintf(fid,'%25.16e',max(abs(grad)));
fprintf(fid,'\n');

% Min. eigenvalue of hessian
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Min. Eig. of Hess');
fprintf(fid,'%25.16e',min(abs(eig(Hess))));
fprintf(fid,'\n');

% Condition number of hessian
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Condition number of Hess');
fprintf(fid,'%25.16e',cond(Hess));
fprintf(fid,'\n');

% Number of free parameters in model
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Number of parameters');
fprintf(fid,'%25.16e',nFree);
fprintf(fid,'\n');

% Sample size
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Sample size');
fprintf(fid,'%25.16e',nHH);
fprintf(fid,'\n');
 
% BIC criterion
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'BIC');
fprintf(fid,'%25.16e',BIC);
fprintf(fid,'\n');

% Elapsed time during estimation
if TimeFactor==60
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Time (mins.)');
elseif TimeFactor==3600
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Time (hours)');
end
fprintf(fid,'%25.16e',timings);

fclose(fid);
