function [xFree2,beta2,C,CDiag,COffDiag, ...
          StandardErrors2,SIG,SIG_SE,BIC2] = ...
    PrintEstimationResults_Model2(xoptimal2,LikeValue2,grad2,Hess2,  ...
                                  timings2,TimeFactor,               ...
                                  iFree2,beta2,CDiag,COffDiag,RCDim,RCRank, ...
                                  nFree2,nHH,OutFile2,               ...
                                  DeltaXLabels,DeltaZLabels)

xFree2=xoptimal2;
[beta2,C,CDiag,COffDiag] = ...
   MapFreeToStructural(xFree2,iFree2,beta2,CDiag,COffDiag,RCDim);

StandardErrors2=full(sqrt(diag(inv(Hess2))));
InvH = inv(Hess2);
index = [iFree2.CDiag{2};iFree2.COffDiag{2}];
InvH = InvH(index,index); 
[SIG,SIG_SE]= ComputeSE(C,InvH,iFree2,RCDim);
BIC2 = 2*LikeValue2+nFree2*log(nHH);

fid=fopen(OutFile2,'w');
LabelWidth=30;
for i1=1:size(beta2,1)
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],DeltaXLabels{i1});
  % Print parameter estimate and Standard error for free parms.  
  if any(iFree2.beta{1}==i1)
    % iX used to select element of xFree2 corresponding to beta2(i1)
    iX = iFree2.beta{2}(iFree2.beta{1}==i1);
    fprintf(fid,'%-5d %25.16e %25.16e %25.16e', ...
         [i1 beta2(i1) StandardErrors2(iX) beta2(i1)./StandardErrors2(iX)]);
  else
  % Print parameter value and zero for fixed parameters.
    fprintf(fid,'%-5d %25.16e %25.16e',[i1 beta2(i1) 0.0]);
  end

  fprintf(fid,'\n');
end

CovMatrixFlag=1; % 1 = print cholesky decomposition of sigma
                 % 2 = print covariance matrix
if CovMatrixFlag==1
  for iColumn=1:RCRank
    CurrentLabel = ['C(',DeltaZLabels{iColumn},',',DeltaZLabels{iColumn},')'];
    fprintf(fid,['%-',int2str(LabelWidth+2),'s'],CurrentLabel);
    % elements of xFree2 corresponding to current element of CDiag
    if any(iFree2.CDiag{1}==iColumn)
      iX = iFree2.CDiag{2}(iFree2.CDiag{1}==iColumn);
      fprintf(fid,'%-5d %25.16e %25.16e %25.16e', ...
            [iColumn CDiag(iColumn) StandardErrors2(iX), ...
             CDiag(iColumn)/StandardErrors2(iX)]);
    else
      % Print parameter value and zero for fixed parameters.
      fprintf(fid,'%-5d %25.16e %25.16e',[iColumn CDiag(iColumn) 0.0]);
    end
    fprintf(fid,'\n');

    for iRow=iColumn+1:RCDim
      index = (iRow-1)*(iRow-2)/2 + iColumn;
      CurrentLabel = ['C(',DeltaZLabels{iRow},',',DeltaZLabels{iColumn},')'];
      fprintf(fid,['%-',int2str(LabelWidth+2),'s'],CurrentLabel);
      if any(iFree2.COffDiag{1}==index)
        % select element of xFree2 corresponding to current element of
        % COffDiag
        iX = iFree2.COffDiag{2}(iFree2.COffDiag{1}==index);
        fprintf(fid,'%-5d %25.16e %25.16e %25.16e', ...
        [index COffDiag(index) StandardErrors2(iX), ...
           COffDiag(index)/StandardErrors2(iX)]);
      else
        fprintf(fid,'%-5d %25.16e %25.16e',[index COffDiag(index) 0.0]);
      end
      fprintf(fid,'\n');
    end
  end
     
elseif CovMatrixFlag==2
  for iColumn=1:RCRank
  for iRow=iColumn:RCDim
    iCurrent = RCDim*(iColumn-1)+iRow;
    if iColumn==iRow
      CurrentLabel = [DeltaZLabels{iColumn},'_sig2'];
    else
      CurrentLabel = [DeltaZLabels{iRow},'_',DeltaZLabels{iColumn},'_cov'];    
    end
    fprintf(fid,['%-',int2str(LabelWidth+2),'s'],CurrentLabel);
    fprintf(fid,'%-5d %25.16e %25.16e %25.16e', ...
            [iCurrent SIG(iRow,iColumn) SIG_SE(iRow,iColumn), ...
             SIG(iRow,iColumn)./SIG_SE(iRow,iColumn)]);
    fprintf(fid,'\n');
  end
  end
end
% Value of likelihood
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Likelihood');
fprintf(fid,'%25.16e',LikeValue2);
fprintf(fid,'\n');

% max value of gradient of likelihood
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Max. Grad.');
fprintf(fid,'%25.16e',max(abs(grad2)));
fprintf(fid,'\n');

% Min. eigenvalue of hessian
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Min. Eig. of Hess');
fprintf(fid,'%25.16e',min(abs(eig(Hess2))));
fprintf(fid,'\n');

% Condition number of hessian
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Condition number of Hess');
fprintf(fid,'%25.16e',cond(Hess2));
fprintf(fid,'\n');

% Number of free parameters in model
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Number of parameters');
fprintf(fid,'%25.16e',nFree2);
fprintf(fid,'\n');

% Sample size
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Sample size');
fprintf(fid,'%25.16e',nHH);
fprintf(fid,'\n');
 
% BIC criterion
fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'BIC');
fprintf(fid,'%25.16e',BIC2);
fprintf(fid,'\n');

% Elapsed time during estimation
if TimeFactor==60
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Time (mins.)');
elseif TimeFactor==3600
  fprintf(fid,['%-',int2str(LabelWidth+2),'s'],'Time (hours)');
end
fprintf(fid,'%25.16e',timings2);

fclose(fid);
