function [x,w]=gauleg(n)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate nodes and weights for Gauss-Legendre integration on [-1,1]
%
% x	= (n x 1) nodes
% w	= (n x 1) weights
% n	= (1 x 1) number of nodes to use

tol=3e-11;
x=zeros(n,1);
w=zeros(n,1);

m=floor((n+1)/2);
xm=0;
x1=1;
for i=1:m
  z=cos(pi*(i-0.25)/(n+0.5));
  z1=z+1;
  while abs(z-z1)>tol
    p1=1;
    p2=0;
    for j=1:n
      p3=p2;
      p2=p1;
      p1=((2*j-1)*z*p2-(j-1)*p3)/j;
    end
    pp=n*(z*p1-p2)/(z*z-1);
    z1=z;
    z=z1-p1/pp;
  end
  x(i,1)=xm-x1*z;
  x(n+1-i,1)=xm+x1*z;
  w(i)=2*x1/((1-z*z)*pp*pp);
  w(n+1-i)=w(i);
end    
