function [y,fail]=zbrent2(func,x1,x2)
% [y,fail]=zbrent(func,x1,x2)
%
% Uses Brent's method to search the interval [x1 x2]
% for a zero of the function.
% y = zero of function
% fail = error code 1=fail 0=success

tolx = 1e-8;
%tolf = 1e-8;
itmax=1000;
DisplayFlag=0;

N    = size(x1,1);
fail = true(N,1);
%y    = zeros(N,1);

f1 = func(x1,fail);
f2 = func(x2,fail);

i1 = (f1.*f2>0);
while any(i1)
  x1(i1)=x1(i1)-1.6*(x2(i1)-x1(i1));
  x2(i1)=x2(i1)+1.6*(x2(i1)-x1(i1));
  f1(i1) = func(x1(i1),i1);
  f2(i1) = func(x2(i1),i1);
  i1 = (f1.*f2>0);
end

if any(f1==0)
  i1 = (f1==0);
  fail(i1) = ~fail(i1);
  x2(i1)   = x1(i1);
  %y(i1)    = x1(i1);
end
if any(f2==0 & f1~=0)
  i1       = (f2==0 & f1~=0);
  fail(i1) = fail(i1);
  %y(i1)    = x2(i1);
end

if any(f2~=0) || any(f1~=0)
  f3 = f2;
  x3 = zeros(N,1);
  D  = zeros(N,1);
  E  = zeros(N,1);
  S  = zeros(N,1);
  P  = zeros(N,1);
  Q  = zeros(N,1);
  
  DisplayStats = zeros(itmax,3); 
  for iter=1:itmax
    % rename x1,x2,x3 and adjust bounding interval D
    i1 = (fail & (f2.*f3>0));
    if any(i1)	
      x3(i1) = x1(i1);
      f3(i1) = f1(i1); 
      D(i1)  = x2(i1)-x1(i1);
      E(i1)  = D(i1);
    end;
    
    i1 = (fail & (abs(f3)<abs(f2)));
    if any(i1)
      x1(i1)=x2(i1);
      x2(i1)=x3(i1);
      x3(i1)=x1(i1);
      f1(i1)=f2(i1);
      f2(i1)=f3(i1);
      f3(i1)=f1(i1);
    end

    %Convergence check
    tol=2*eps*abs(x2)+0.5*tolx;	
    xm=0.5*(x3-x2);
    fail = (fail & abs(xm)>tol & f2~=0);
    if all(~fail)
      break
    end
    if DisplayFlag==1
      DisplayStats(iter,:) = [max(abs(xm)) max(abs(f2)) sum(fail)];
      fprintf(1,'%-10s %-10s %-10s \n','Max. Int.','Max. F2','No. Fail');
      for j1=1:iter
        fprintf(1,'%-10.4f %-10.4f %-10d \n',DisplayStats(j1,:));
      end
      %fprintf(1,'\n')
    end
    % Attempt inverse quadratic interpolation
    i2 = (fail & (abs(E)>=tol & abs(f1)>abs(f2)));
    if any(i2)
      S(i2)=f2(i2)./f1(i2);
      %xm2 = xm(i2);
      i3 = i2 & (x1==x3);
      i4 = i2 & (x1~=x3);
      if any(i3)
        P(i3)=2*xm(i3).*S(i3);
        Q(i3)=1-S(i3);
      end
      if any(i4)
        Q(i4)=f1(i4)./f3(i4);
        R=f2(i4)./f3(i4);
        P(i4)=S(i4).*(2*xm(i4).*Q(i4).*(Q(i4)-R)-(x2(i4)-x1(i4)).*(R-1));
        Q(i4)=(Q(i4)-1).*(R-1).*(S(i4)-1);
      end;

      % Check whether in bounds 
      Q(P>0) = -Q(P>0);
      P=abs(P);
      
      t1 =min([3*xm.*Q-abs(tol.*Q), abs(E.*Q)],[],2);
      
      % accept interpolation
      i3 = i2 & (2*P<t1);
      E(i3) = D(i3);
      D(i3) = P(i3)./Q(i3);
      
      % otherwise bijection
      i4 = (i2 & (2*P>=t1));
      %i4 = (2*P>=t1);
      D(i4)=xm(i4);	% Interpolation failed, use bisection
      E(i4)=D(i4);
    end
    
    % Bounds decreasing too slow, use bisection.
    if any(~i2)
      D(~i2)=xm(~i2);
      E(~i2)=D(~i2);
    end
    
    % Move last best guess to x1
    x1(fail)=x2(fail);
    f1(fail)=f2(fail);

    % Evaluate new trial root
    i1 = (fail & abs(D)>tol);
    x2(i1)=x2(i1)+D(i1);
    i1 = (fail & abs(D)<=tol);
    x2(i1)=x2(i1)+sign(xm(i1)).*tol(i1);

    f2(fail) = func(x2(fail),fail);
  end;		% end for iter=1:itmax

  if iter==itmax, error('Maximum iterations reached in zbrent.'), end;
end
y=x2; 
%f=f2;
