function  CV = ComputeIntegral_Dagsvik(iQuad,V0,YH,HHPrice, ...
                                       X,Z,basis,EstColumn,ZIndex,iNonZero, ...
                                       xFree2,iFree2,beta2,CDiag,COffDiag,  ...
                                       LogNormalFlag,LogNormalIndex,        ...
                                       noptions,nHH,RCDim,RCRank,Nodes,nQuadAll, ...
                                       method)
% Several methods to compute integral in the Dagsvik and Karlstrom (2005) 
% formula.
%
% Revision history
% 2017MAR19  Cleaned version for publication.
if nargin<24
  method=1; % 1 = Gauss-Legendre
            % 2 = quad(fun,a,b,tol):   simpson's rule
            % 3 = quadgk(fun,a,b,'AbsTol',1e-6,'RelTol',1e-6): Gauss-Kronod adaptive rule
            % 4 = quadl(fun,a,b,tol): Gauss-Lobatto rule
            % 5 = quadv(fun,a,b,tol): vectorized version of quad
end
          
if method==1          
% quadrature nodes for Gauss-Legendre integration on [-1,1]

nY = 51;
[uY,wY]=gauleg(nY);

% size(YH) = (noptions*nHH x 1)
% size(V0) = (noptions*nHH x 1)
V0    = reshape(V0,[noptions nHH]);
YH    = reshape(YH,[noptions nHH]);

X0=X;
Z0=Z;

EY = zeros(nHH,1);
for i1=1:noptions
  % temp1 = integral over uY in Dagsvik formula
  temp1 = zeros(nHH,1);
  temp2     = zeros(nHH,nY);
  for i2=1:nY
      
    income = reshape(repmat(0.5*(1+uY(i2))*YH(i1,:),[noptions 1]),noptions*nHH,1);  
    [X,Z]=UpdatePriceTerms(income - HHPrice,X0,Z0,basis,EstColumn,ZIndex, ...
                           iNonZero,RCDim);

    % size(V1) = (noptions x nHH x nQuadAll)
    V1=ComputeUtility(xFree2,iFree2,beta2,CDiag,COffDiag, ...
                          X,Z,LogNormalFlag,LogNormalIndex,   ...
                          noptions,nHH,RCDim,RCRank,Nodes,nQuadAll,iQuad);
    MaxV = max(V1,V0);
    MaxV2 = max(MaxV,[],1);
    temp2(:,i2) = exp(V0(i1,:).'-MaxV2.')./(sum(exp(MaxV-repmat(MaxV2,[noptions 1])),1).');
    temp1 = temp1 + 0.5*wY(i2).*temp2(:,i2).*(YH(i1,:).');
  end
  EY = EY + temp1;
end

elseif method>1 && method<6
  % use matlab integration tools
  %    quad
  %    quadv
  %    quadl
  %    etc.
  V0    = reshape(V0,[noptions nHH]);
  YH    = reshape(YH,[noptions nHH]);
  EY    = zeros(nHH,1);
  
  tol=1e-8;
  if exist('quadv','file')==0
    quadfunc = @(fun,a,b,tol)integral(fun,a,b,'AbsTol',tol,'RelTol',tol);
  else
    if method==5 
      quadfunc = @(fun,a,b,tol)quadv(fun,a,b,tol);  
    elseif method==4
      quadfunc = @(fun,a,b,tol)quadl(fun,a,b,tol);
    end
  end

  for i1=1:nHH
    index = (i1-1)*noptions +(1:noptions)';
    TempX.xInteraction = X.xInteraction(index,:);
    TempX.X            = X.X(index,:);
    TempX.GradX        = X.GradX(index,:);
    TempX.HessX        = X.HessX(index,:);
    TempZ.Z            = Z.Z(index,:);
    TempZ.GradZ        = Z.GradZ(index,:);
    TempZ.HessZ        = Z.HessZ(index,:);
    if size(Nodes,1)>nQuadAll
      % Monte carlo integration nodes
      % different draws for each HH
      % Nodes = (nHH*nQuadAll,RCDim)
      Nodes = reshape(Nodes,[nHH nQuadAll RCDim]);
      Nodes = reshape(Nodes(i1,:,:),[nQuadAll RCDim]);
    end

    for j1=1:noptions
      fun = @(y)DagsvikIntegrand(y,V0(:,i1),V0(j1,i1),TempX,TempZ, ...
                                 HHPrice(index),    ...
                                 basis,EstColumn,ZIndex,iNonZero(index), ...
                                 xFree2,iFree2,beta2,CDiag,COffDiag,    ...
                                 LogNormalFlag,LogNormalIndex,          ...
                                 noptions,RCDim,RCRank,Nodes,nQuadAll,iQuad);
       EY(i1) = EY(i1)+quadfunc(fun,0,YH(j1,i1),tol);
    end
  end
elseif method==6
  % take summation in Dagsvik Karlstrom formula inside integral  
  EY = ComputeIntegral_Dagsvik2(YH,V0,X,Z,HHPrice,iNonZero,            ...
                  basis,EstColumn,ZIndex,xFree2,iFree2,beta2,CDiag,    ...
                  COffDiag,LogNormalFlag,LogNormalIndex,noptions,nHH,  ...
                  RCDim,RCRank,Nodes,nQuadAll,iQuad);
end

CV = EY - X.GrossExpenditure(1:noptions:nHH*noptions);