function EY = ComputeIntegral_Dagsvik2(YH,V0,X,Z,HHPrice,iNonZero,     ...
                  basis,EstColumn,ZIndex,xFree2,iFree2,beta2,CDiag,    ...
                  COffDiag,LogNormalFlag,LogNormalIndex,noptions,nHH,  ...
                  RCDim,RCRank,Nodes,nQuadAll,iQuad)
% Compute integral in Dagsvik and Karlstrom (2005) formula.
%   In this version, the summation is taekn inside the integral.
%
% Revision history
% 2017MAR19 CLeaned version for publication.

% YH = (noptions x nHH)
% V0 = (noptions x nHH)
YH = reshape(YH,[noptions nHH]);
V0 = reshape(V0,[noptions nHH]);
EY = zeros(nHH,1);

for i1=1:nHH
  [YHSorted,iSort] = sort(YH(:,i1));
  V0Sorted = V0(iSort,i1);
  index = (i1-1)*noptions + (1:noptions)';
  X0.X     = X.X(index,:);
  X0.GradX = X.GradX(index,:);
  X0.HessX = X.HessX(index,:);
  X0.xInteraction = X.xInteraction(index,:);
  Z0.Z     = Z.Z(index,:);
  Z0.GradZ = Z.GradZ(index,:);
  Z0.HessZ = Z.HessZ(index,:);
  QuadHandle = @(a,b,V0Sorted)QuadFunc(a,b,V0Sorted,       ...
                   V0(:,i1),X0,Z0,HHPrice(index),          ...
                   basis,EstColumn,ZIndex,iNonZero(index), ...
                   xFree2,iFree2,beta2,CDiag,COffDiag,     ...
                   LogNormalFlag,LogNormalIndex,           ...
                   noptions,RCDim,RCRank,Nodes,nQuadAll,iQuad);

  for j1=1:noptions
    if j1==1
      t1 = QuadHandle(0,YHSorted(j1),V0Sorted(j1:noptions));
    else
      t1 = QuadHandle(YHSorted(j1-1),YHSorted(j1),V0Sorted(j1:noptions));
    end
    EY(i1) = EY(i1)+t1;
  end
end  