function WelfareResults = ComputeWelfare(xFree2,iFree2,beta2,CDiag,    ...
                                         COffDiag,HHID,                ... 
                                         HHPrice,HHTaxPrice,           ...
                                         HHNashConsumerPrice,          ...
                                         LogNormalFlag,LogNormalIndex, ...
                                         basis,EstColumn,ZIndex,       ...
                                         noptions,nHH,RCDim,RCRank, ...
                                         TempDir,Nodes,Weights,nQuadAll)

% function WelfareResults = ComputeWelfare(BaseTaxDataFile,HHTaxResultsFile)
%
% Compute approximate compensating variation:
%     CV =  ( log(sum(V_j_new)) - log(sum(V_j_old) ) / dV_j/d_p
%            (assuming marginal utility of income constant and
%
%            dV_j/dp = marginal utility of income
%
% See Rosen and Small (1981), McFadden (1981, 1995) or Nevo (2000)
%
% WelfareResults  = (nHH x 3) =  [HHID CV_Tax CV_Nash]
%
% Revision history
%
% 2017MAR19  Cleaned version for publication
StartTime=clock;
DisplayFlag=0;

%% Compute base utility and MU of income
% load base values of (X,Z,GradX,HessX)
load(fullfile(TempDir,'X.mat'));
CurrentTime=clock;
if DisplayFlag==1
  disp(['Current time: ',int2str(CurrentTime(4)),':',int2str(CurrentTime(5))]);
  disp('Computing base utility.')
end
  tic;
  % size(MaxV0) = (nHH x nQuadAll)
  [V0,GradV0,MaxV0]=ComputeExpUtility(xFree2,iFree2,beta2,CDiag,COffDiag, ...
                                      X,Z,LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                                      noptions,nHH,RCDim,RCRank,Nodes,nQuadAll);
  t1=toc/60;
  CurrentTime=clock;
if DisplayFlag==1
  disp(['Base utility computation time: ',int2str(t1),' minutes.']);
  disp(['Elapsed time: ',num2str(etime(CurrentTime,StartTime)/60),' minutes.']);
end
%% Compute welfare impact of tax increase: NO FIRM RESPONSE
% Replace HHPrice with HHTaxPrice

iNonZero = HHPrice~=0;
HHTaxExpenditure = X.GrossExpenditure - HHTaxPrice;
[X,Z]=UpdatePriceTerms(HHTaxExpenditure,X,Z,basis,EstColumn,ZIndex,iNonZero, ...
                       RCDim);
% Compute new utility: Tax:  NO FIRM RESPONSE
CurrentTime=clock;
if DisplayFlag==1
  disp(['Current time: ',int2str(CurrentTime(4)),':',int2str(CurrentTime(5))]);
  disp('Computing TAX utility.')
end
tic;
[V1,~,MaxV1]=ComputeExpUtility(xFree2,iFree2,beta2,CDiag,COffDiag,X,Z, ...
                               LogNormalFlag,LogNormalIndex,EstColumn,ZIndex,noptions, ...
                               nHH,RCDim,RCRank,Nodes,nQuadAll);
t1=toc/60;
CurrentTime=clock;
if DisplayFlag==1
  disp(['TAX utility computation time: ',int2str(t1),' minutes.']);
  disp(['Elapsed time: ',num2str(etime(CurrentTime,StartTime)/60),' minutes.']);
end
%CV_TaxOnly = (MaxV1-MaxV0+log(V1(:,1))-log(V0(:,1)))./GradV0(:,1);
% if CV(n,q)<0 then reset to zero.
% CV(n,q) is <0 for a small fraction of draws from the r.c. distribution
CV_TaxOnly = max(0,((MaxV1-MaxV0+log(V1)-log(V0))./GradV0)) ...
             *Weights;

%%  Welfare impact of tax increase: NEW NASH EQUILIBRIUM
% reload base values of (X,Z,GradX,HessX)
load(fullfile(TempDir,'X.mat'));

HHNashExpenditure = X.GrossExpenditure - HHNashConsumerPrice;
[X,Z]=UpdatePriceTerms(HHNashExpenditure,X,Z,basis, ...
                       EstColumn,ZIndex,iNonZero,RCDim);

% Compute new utility: Tax:  NEW NASH EQUILIBRIUM
if DisplayFlag==1
  disp('Computing NE utility.')
end
[V1,~,MaxV1]=ComputeExpUtility(xFree2,iFree2,beta2,CDiag,COffDiag, ...
                               X,Z,LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                               noptions,nHH,RCDim,RCRank,Nodes,nQuadAll);
t1=toc/60;
CurrentTime=clock;
if DisplayFlag==1
  disp(['NE utility computation time: ',int2str(t1),' minutes.']);
  disp(['Elapsed time: ',num2str(etime(CurrentTime,StartTime)/60),' minutes.']);
end
%CV_Nash = (MaxV1-MaxV0+log(V1(:,1))-log(V0(:,1)))./GradV0(:,1);
% if CV(n,q)<0, reset to zer0
% CV(n,:)<0 for a small fraction of draws from the r.c. distribution
CV_Nash = max(0,((MaxV1-MaxV0+log(V1)-log(V0))./GradV0)) ...
          *Weights;

% Welfare results
%    1    HHID
%    2    CV_TAX
%    3    CV_Nash
WelfareResults = [HHID(1:noptions:noptions*(nHH-1)+1), ...
                  CV_TaxOnly,                         ...
                  CV_Nash];
if DisplayFlag==1
  disp(['Total time: ',num2str(etime(clock,StartTime)/60),' minutes.']);              
end
