function WelfareResults = ...
    ComputeWelfare_ExAnte(xFree2,iFree2,beta2,CDiag,COffDiag, ....
                          HHID,HHPrice,HHTaxPrice,           ...
                          HHNashConsumerPrice,          ...
                          LogNormalFlag,LogNormalIndex, ...
                          basis,EstColumn,ZIndex,       ...
                          noptions,nHH,RCDim,RCRank, ...
                          TempDir,Nodes,Weights,nQuadAll)

% function WelfareResults = ComputeWelfare(BaseTaxDataFile,HHTaxResultsFile)
%
% Compute CV based on ex ante utility
%    E(u(y-p0) ) = E( u(y+CV-p1) )
%
% WelfareResults  = (nHH x 3) =  [HHID CV_Tax CV_Nash]
%
% Revision history
% 2017MAR19   Cleaned version for publication.
StartTime=clock;
DisplayFlag=0;

%% Compute base utility and MU of income
% load base values of (X,Z,GradX,HessX)
load(fullfile(TempDir,'X.mat'));
CurrentTime=clock;
if DisplayFlag==1
  disp(['Current time: ',int2str(CurrentTime(4)),':',int2str(CurrentTime(5))]);
  disp('Computing base utility.')
end
  tic;
  % size(V0) = (nHH x nQuad)
  [V0,~,MaxV0]=ComputeExpUtility(xFree2,iFree2,beta2,CDiag,COffDiag, ...
                                 X,Z,LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
                                 noptions,nHH,RCDim,RCRank,Nodes,nQuadAll);
  V0 = MaxV0+log(V0);
  t1=toc/60;
  CurrentTime=clock;
if DisplayFlag==1
  disp(['Base utility computation time: ',int2str(t1),' minutes.']);
  disp(['Elapsed time: ',num2str(etime(CurrentTime,StartTime)/60),' minutes.']);
end
%% Compute welfare impact of tax increase: NO FIRM RESPONSE
% Replace HHPrice with HHTaxPrice

iNonZero = HHPrice~=0;
str1 = {'No Firm response CV','New Nash CV'};
CV = zeros(nHH,nQuadAll,2);
for iTax=1:2

  % Compute CV Tax:
  %  iTax == 1: NO FIRM RESPONSE
  %  iTax == 2: New Nash Equilibrium
  CurrentTime=clock;
if DisplayFlag==1
  disp(['Current time: ',int2str(CurrentTime(4)),':',int2str(CurrentTime(5))]);
  disp(['Computing ',str1{iTax}])
end
  tic;

  if iTax==1
    NewExpenditure=X.GrossExpenditure - HHTaxPrice;
  else
    NewExpenditure=X.GrossExpenditure - HHNashConsumerPrice;
  end
  
  ZeroHandle = ...
    @(CV,V0,iq)ExpectedUtilityResidual(CV,V0,iq,xFree2,iFree2, ...
                                       beta2,CDiag,COffDiag, ...
                                       LogNormalFlag,LogNormalIndex, ...
                                       EstColumn,ZIndex, ...
                                       noptions,nHH,RCDim,RCRank,Nodes,nQuadAll, ...
                                       NewExpenditure,X,Z,basis,iNonZero);
  
  parfor iq=1:nQuadAll
    CVL=zeros(nHH,1);
    
    ZeroHandle2 = @(CV)ZeroHandle(CV,V0(:,iq),iq);
%    ZeroHandle = ...
%        @(CV)ExpectedUtilityResidual(CV,V0(:,iq),iq,xFree2,iFree2,beta2,CDiag,COffDiag, ...
%                   LogNormalFlag,LogNormalIndex,EstColumn,ZIndex, ...
%                   noptions,nHH,RCDim,RCRank,Nodes,nQuadAll, ...
%                   NewExpenditure,X,Z,basis,iNonZero);
    f1 = ZeroHandle2(CVL);
    CVH = CVL;
    i1 = (f1<=0);
    CVH(i1) = 0.1;
    i2= (f1>0);
    CVL(i2) = -0.1;
    f1 = ZeroHandle2(CVL);
    f2 = ZeroHandle2(CVH);
    iter=0;
    CVMIN = -1.5;
    CVMAX = 1.5;
    while any(f1.*f2>0)
      if all(f1.*f2<=0 | (f1.*f2>0 & CVL==CVMIN & CVH==CVMAX))
        break
      end
      iter=iter+1;
      i1 = f1.*f2>0 & abs(f1)<abs(f2) ;
      i2 = f1.*f2>0 & abs(f1)>=abs(f2);   
      CVL(i1)=max(CVL(i1)-.1,CVMIN);
      CVH(i2)=min(CVH(i2)+0.1,CVMAX);
      i3 = (f1.*f2>0 & CVL==CVMIN & CVH<CVMAX);
      CVH(i3) = min(CVH(i3)+0.5,CVMAX);
      i3 = (f1.*f2>0 & CVL>CVMIN & CVH==CVMAX);
      CVL(i3) = max(CVL(i3)-0.5,CVMIN);
   
      i3 = f1.*f2>0 & (CVL>CVMIN | CVH<CVMAX);
      if sum(i3)>0
        f1=ZeroHandle2(CVL);
        f2=ZeroHandle2(CVH);
      end
      display([iter sum(f1.*f2>0)]);
    end % while any(f1.*f2>0

    if any(f1.*f2>0)
      i1 = find(f1.*f2>0);
      for i2=1:length(i1)
        options = optimset('Display','iter');
        CV2Handle = @(CV)ExpectedUtilityResidual2(CV,CVL,ZeroHandle2,i1(i2));
        CVL(i1(i2)) = fminbnd(CV2Handle,-0.5,0.5,options);
        CVH(i1(i2)) = CVL(i1(i2));
      end
    end

    CV(:,iq,iTax) = bisect(ZeroHandle2,CVL,CVH);
  end
  t1=toc/60;
  CurrentTime=clock;
  if DisplayFlag==1
    disp([str1{iTax},' computation time: ',int2str(t1),' minutes.']);
    disp(['Elapsed time: ',num2str(etime(CurrentTime,StartTime)/60),' minutes.']);
  end
end

% Welfare results
%    1    HHID
%    2    CV(:,:,1)*Weights  No Firm Response
%    3    CV(:,:,2)*Weights  New Nash Equilibrium
WelfareResults = [HHID(1:noptions:noptions*(nHH-1)+1), ...
                  CV(:,:,1)*Weights,                         ...
                  CV(:,:,2)*Weights];
if DisplayFlag==1
  disp(['Total time: ',num2str(etime(clock,StartTime)/60),' minutes.']);              
end