/*
CreateMatlabData.do

This file loads the Stata data file, creates a few new variables, sorts the data 
and outputs a log file and a raw data file to be loaded into Matlab.

Revision history
2017MAR26    Final version for publication

*/

* Directory names
global Path "C:/GriffithNesheimOConnell.2017.QE"

global RawDir     "$Path/Stata_files/Estimation"
global MatlabDir  "$Path//Stata_files/Estimation"

global RawDataFile    "${RawDir}/data.dta"
global MatlabDataFile "${MatlabDir}/MatlabRawData.raw"
global LogFile        "${MatlabDir}/MatlabRawData.log

* Copy ownershipdata to matlab data directory
!cp "${RawDir}/ownership.raw" "${MatlabDir}"


use ${RawDataFile},clear

gen zz1 = (prod==1)
order zz1, before(zz2)

* Gross expenditure
gen grossexp = netexp+price
gen grossexp2 = grossexp*grossexp

* generate income dummies
*  hhincome
forvalues i1=0/8 {
  cap drop inc`i1'
  gen inc`i1'= (hhincome==`i1')
}

* 1) rescale pack size by a) hheqsize,b) hhmembers
gen size500_scaled1 = size500/hheqsize
gen size1000_scaled1 = size1000/hheqsize
gen size500_scaled2 = size500/hhmember
gen size1000_scaled2 = size1000/hhmember

label variable size500_scaled1 "Pack size 500 g / hheqsize"  
label variable size1000_scaled1 "Pack size 1000 g / hheqsize"  
label variable size500_scaled2 "Pack size 500 g / hhmember"  
label variable size1000_scaled2 "Pack size 1000 g / hhmember"  

gen size500_obese_scaled1  = size500_obese/hheqsize
gen size1000_obese_scaled1 = size1000_obese/hheqsize
gen size500_obese_scaled2  = size500_obese/hhmember
gen size1000_obese_scaled2 = size1000_obese/hhmember
label variable size500_obese_scaled1 "Pack size 500 g * obese / hheqsize"  
label variable size1000_obese_scaled1 "Pack size 1000 g * obese / hheqsize"  
label variable size500_obese_scaled2 "Pack size 500 g * obese / hhmember"  
label variable size1000_obese_scaled2 "Pack size 1000 g * obese / hhmember"  

* 2) rescale expenditure and price by a) hheqsize, b) hhmembers
gen netexp_scaled1 = netexp/hheqsize
gen netexp_scaled2 = netexp/hhmember
gen price_scaled1  = price/hheqsize
gen price_scaled2  = price/hhmember
gen grossexp_scaled1 = grossexp/hheqsize
gen grossexp_scaled2 = grossexp/hhmember
gen grossexp2_scaled1= grossexp_scaled1 * grossexp_scaled1
gen grossexp2_scaled2= grossexp_scaled2 * grossexp_scaled2
label variable netexp_scaled1 "y - p / hheqsize"
label variable netexp_scaled2 "y - p / hhmember"
label variable price_scaled1 "price / hheqsize"
label variable price_scaled2 "price / hhmember"
label variable grossexp_scaled1 "y  / hheqsize"
label variable grossexp_scaled2 "y  / hhmember"
label variable grossexp2_scaled1 " (y / hheqsize)^2 "
label variable grossexp2_scaled2 " (y/ hhmember)^2 "

* 3) interact labour stat with outside option
* 
levelsof labour,local(levels)
foreach i1 of local levels {
  gen labour`i1' = labour==`i1'
  label variable labour`i1' "Labour status `i1'"
}
foreach i1 of local levels {
  gen zz1_labour`i1' = zz1 * labour`i1'
  label variable zz1_labour`i1' "zz1 * labour `i1'"
}
 
* interact hheqsize with zz1
gen zz1_scaled1 = zz1/hheqsize
gen zz1_hheqsize = zz1*hheqsize
gen zz1_scaled2 = zz1/hhmember
gen zz1_hhsize  = zz1*hhmember
label variable zz1_scaled1 "zz1 /hheqsize"
label variable zz1_hheqsize " zz1 * hheqsize"
label variable zz1_scaled2 "zz1 / hhmember"
label variable zz1_hhsize "zz1 * hhmember"

levelsof hhmember,local(levels)
foreach i1 of local levels {
  gen hhsize`i1' = hhmember==`i1'
  label variable hhsize`i1' "hhmember == `i1'"
} 
foreach i1 of local levels {
  gen zz1_hhsize`i1' = zz1*hhsize`i1'
  label variable zz1_hhsize`i1' "zz1 * hhsize `i1'"
  
  gen grossexp_hhsize`i1' = grossexp*hhsize`i1'
  label variable grossexp_hhsize`i1' "gross exp * hhsize `i1'"
  gen grossexp2_hhsize`i1' = grossexp2*hhsize`i1'
  label variable grossexp2_hhsize`i1' "gross exp^2 * hhsize `i1'"
}

*rescale netexp data using scale
global scale=1
global ScaleFlag=0
if ${ScaleFlag}==1 {
  replace price = price/${scale}
  replace netexp=netexp/${scale}
  replace netexp2=netexp*netexp
  replace netexp3 = netexp2*netexp
  replace but_netexp=but_netexp/${scale}
  replace but_netexp2 = but_netexp*but_netexp
  replace but_netexp3 = but*netexp3
}

order grossexp_hhsize*,after(grossexp2)

sort hh choicesituation choice prod
set more off
log using ${LogFile},replace
des,numbers
des,fullname
log close

export delimited using ${MatlabDataFile}, nolabel replace
