cap log close
clear
set more off

global Path "C:/GriffithNesheimOConnell.2017.QE"
global P    "$Path\Stata_files\Estimation"

**************************************************************************
**Set of included products
**************************************************************************

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_153_2010.dta",clear

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_209_2010.dta"

gen year  = int(date/10000)
gen month = int(date/100)-100*year

bysort prodcode month: gen N = _N
bysort prodcode month: keep if _n==1

**Keep only products present in all markets
bysort prodcode: gen obs = _N
gen include = obs==12

collapse (sum) N,by(prodcode include)

egen base = sum(N)
gen totshare = (N/base)*100

**Keep only products with a market share above 0.5%
replace include = 0 if totshare<0.5

table include,c(sum totshare)

keep prodcode include
sa "$P\included_products.dta",replace

**************************************************************************
**Compute prices
**************************************************************************

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_153_2010.dta",clear

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_209_2010.dta"

merge m:1 prodcode using "$P\included_products.dta"
keep if include==1
drop _m include

gen year  = int(date/10000)
gen month = int(date/100)-100*year

gen price = exp/npacks
drop if price==0

collapse (mean) price,by(prodcode month)

sa "$P/prices.dta",replace

**************************************************************************
**Obtain product attributes
**************************************************************************

u "M:\TNS\extractedfiles\product_attributes\2008-2012\rf153_0812.dta",clear

append using "M:\TNS\extractedfiles\product_attributes\2008-2012\rf209_0812.dta"

merge m:1 prodcode using "$P\included_products.dta"
keep if include==1
drop _m include

keep prodcode productdesc manu brand valueprivatelabels yellowfatstype size

sa "$P\combined_attributes.dta",replace

**************************************************************************
**Obtain nutrients
**************************************************************************

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_153_2010.dta",clear

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_209_2010.dta"

merge m:1 prodcode using "$P\included_products.dta"
keep if include==1
drop _m include

replace saturates = saturates/100
replace sodium    = sodium/100

collapse (median) saturates sodium,by(prodcode)

sa "$P/nutrients.dta",replace

**************************************************************************
**Obtain all 2010 shopping trips
**************************************************************************

u "M:\TNS\extractedfiles\index_files\hh_daily_expenditure_12.dta",clear

gen year  = int(date/10000)
gen month = int(date/100)-100*year
gen dayofmonth = date - year*10000 - month*100

keep if year==2010

merge m:1 year month dayofmonth using "M:\TNS\extractedfiles\index_files\dates_detail.dta"
drop if _m==2
drop _m

collapse (sum) daily_exp_food,by(hhno week)

keep hhno week

sa "$P\shopping_trips.dta",replace

**************************************************************************
**Compute median month in a week
**************************************************************************

u "M:\TNS\extractedfiles\index_files\dates_detail.dta",clear

bysort week: egen median_month = median(month)
replace median_month = int(median_month)

keep if year==2010
keep week median_month
bysort week: keep if _n==1

rename median_month month

sa "$P/month.dta",replace

**************************************************************************
**Obtain purchase data
**************************************************************************

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_153_2010.dta",clear

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_209_2010.dta"

merge m:1 prodcode using "$P\included_products.dta"
drop _m

gen year  = int(date/10000)
gen month = int(date/100)-100*year
gen dayofmonth = date - year*10000 - month*100

merge m:1 year month dayofmonth using "M:\TNS\extractedfiles\index_files\dates_detail.dta"
drop if _m==2
drop _m

collapse (sum) volume npacks,by(hhno week prodcode include)

bysort hhno week: gen n = _n

egen temp = max(include),by(hhno week)

**Number of times a week's purchases excludes an included options
tab temp if n==1
drop if include==0 & temp==1

**Keep purchase in week with largest volume
sort hhno week volume
by hhno week: keep if _n==_N
drop volume

**Number of weeks in the year a household purchases butter/margarine
bysort hhno week: gen g = 1 if _n==1
egen temp2 = sum(g),by(hhno)
tab temp2

drop n N temp temp2 g

**Merge in outside options data
merge 1:1 hhno week using "$P\shopping_trips.dta"
drop if include==0
gen outside = _m==2
replace prodcode = 999999 if outside==1
drop _m include

**Keep households that record shopping at least 40 weeks of the year
bysort hhno: gen N = _N
drop if N<40
drop N

sort hhno week
gen index = _n

sa "$P/purchases.dta",replace

**************************************************************************
**Square data for estimation
**************************************************************************

u "$P/purchases.dta",clear

merge m:1 week using "$P/month.dta"
drop _m

set seed 10
drawnorm x
sort hhno month x
by hhno month: keep if _n==1
drop x

set seed 20
drawnorm x
sort hhno x
by hhno: keep if _n<=5
drop x

sa "$P/purchases_sample.dta",replace

u "$P/purchases_sample.dta",clear

keep index hhno month week

sa "$P/index_vars.dta",replace

u "$P/purchases_sample.dta",clear

keep index prodcode
gen choice = 1
fillin index prodcode
drop _f
replace choice = 0 if choice==.

merge m:1 index using "$P/index_vars.dta"
drop _m

merge m:1 prodcode month using "$P/prices.dta"
drop _m

replace price = 0 if prodcode==999999

merge m:1 prodcode using "$P/nutrients.dta"
drop _m

replace saturates = 0 if prodcode==999999
replace sodium    = 0 if prodcode==999999

merge m:1 prodcode using "$P\combined_attributes.dta"
keep if _m==3|prodcode==999999
drop _m

gen size250 = size=="250 Gm"
gen size500 = size=="500 Gm"
gen size1000= size=="1 Kg"
lab var size250  "Pack size 250g"
lab var size500  "Pack size 500g"
lab var size1000 "Pack size 1Kg"
drop size

gen but    = yellowfatstype=="Standard Butter"
lab var but    "Butter"
drop yellowfatstype

replace brand = "." if prodcode==999999

egen temp = group(brand)
su temp
local pu = r(max)
foreach v of numlist 1(1)`pu' {
   gen zz`v' = (temp==`v')
}
drop temp

encode brand,g(brandd)
drop brand
ren brandd brand

egen choicesituation = group(index)
egen hh = group(hhno)

replace manufacturer = "." if manufacturer==""

egen manu = group(manufacturer)
egen brnd = group(manufacturer brand)
egen prod = group(manufacturer brand prodcode)

sa "$P/pre_matlab.dta",replace

**************************************************************************
**Create household information
**************************************************************************

**Get 52 week weight for 2010

use "M:\TNS\extractedfiles\panel_data\hhpanel2010.dta",clear

keep hhno x93_1
rename x93_1 demweight
egen tot = sum(demweight)

sa "$P/demweight.dta",replace

**Create trip weight

u "$P/purchases_sample.dta",clear

bysort hhno: keep if _n==1

keep hhno

sa "$P/temp.dta",replace

u "M:\TNS\extractedfiles\index_files\hh_daily_expenditure_12.dta",clear

gen year  = int(date/10000)
gen month = int(date/100)-100*year
gen dayofmonth = date - year*10000 - month*100

merge m:1 year month dayofmonth using "M:\TNS\extractedfiles\index_files\dates_detail.dta"
drop _m

drop daily_exp_nonfood daily_exp_food dayofmonth yearweek demyear dayofweek weekday

merge m:1 hhno using "$P/temp.dta"
drop if _m==1
drop _m

egen min_y = min(year),by(hhno)
egen max_y = max(year),by(hhno)

gen begin = min_y==2010
gen end   = max_y==2010

drop min_y max_y
keep if year==2010

bysort hhno week: keep if _n==1
bysort hhno: gen tripweight = _N

egen week2 = group(week)

egen min_week = min(week2),by(hhno)
egen max_week = max(week2),by(hhno)

gen     adjust = 53                  if begin==0 & end==0
replace adjust = 53-min_week+1       if begin==1 & end==0
replace adjust = max_week            if begin==0 & end==1
replace adjust = max_week-min_week+1 if begin==1 & end==1

replace tripweight=tripweight*(53/adjust)

bysort hhno: keep if _n==1
keep hhno tripweight

sa "$P/tripweight.dta",replace

**Create demographic variables

u "M:\TNS\extractedfiles\panel_data\hhpanel_all.dta",clear

merge m:1 hhno using "$P/temp.dta"
drop if _m==1
drop _m

sort hhno demyear
by hhno: replace hhinc = hhinc[_n-1] if hhinc==.
by hhno: replace hhinc = hhinc[_n+1] if hhinc==.
egen m_hhinc = mean(hhinc),by(hhno)
replace hhinc = m_hhinc if hhinc==.

by hhno: replace bmi_group = bmi_group[_n-1] if bmi_group==.
egen m_bmi_group = mean(bmi_group),by(hhno)
replace bmi_group = m_bmi_group if bmi_group==.

keep if demyear==2010

keep hhno hhinc bmi_group hhsize

gen inc_nc  = hhinc==0
gen inc_low = hhinc==1|hhinc==2|hhinc==3
gen inc_hi  = hhinc==4|hhinc==5|hhinc==6|hhinc==7|hhinc==8

gen obese = bmi_group==4|bmi_group==5|bmi_group==6

keep hhno inc_low inc_hi obese hhsize

sa "$P/demogs.dta",replace

**Merge together household information

u "$P/purchases.dta",clear

keep hhno
bysort hhno: keep if _n==1

merge 1:1 hhno using "$P/demweight.dta"
drop if _m==2
drop _m

egen tot2 = sum(demweight)

replace demweight = demweight*(tot/tot2)
drop tot tot2

merge 1:1 hhno using "$P/tripweight.dta"
drop _m

merge 1:1 hhno using "$P/demogs.dta"
drop _m

gen weight = tripweight*demweight
egen tot = sum(weight)
su hhno
local l=r(N)
replace weight = (weight/tot)*`l'
drop tot

sa "$P/household_info.dta",replace

***Obtain expenditure information

u "$P/purchases_sample.dta",clear

bysort hhno: keep if _n==1
keep hhno

sa "$P/hh_sample.dta",replace

use "M:\TNS\extractedfiles\index_files\hh_dailyshop_expenditure_12.dta",clear

gen year  = int(date/10000)
gen month = int(date/100)-100*year
gen dayofmonth = date - year*10000 - month*100

keep if year==2010

merge m:1 year month dayofmonth using "M:\TNS\extractedfiles\index_files\dates_detail.dta"
drop if _m==2
drop _m

gen exp = exp_food+exp_nonfood

collapse (sum) exp exp_food exp_nonfood,by(hhno week)

merge m:1 hhno using "$P/hh_sample.dta"
keep if _m==3
drop _m

collapse (mean) exp_food,by(hhno)

rename exp_food exp
centile exp,centile(5 95)
drop if exp<r(c_1) | exp>r(c_2)

keep hhno exp

sa "$P/net_expenditure_foodt.dta",replace

***Promotion dummy

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_153_2010.dta",clear

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_209_2010.dta"

merge m:1 prodcode using "$P\included_products.dta"
keep if include==1
drop _m include

gen year  = int(date/10000)
gen month = int(date/100)-100*year

gen price = exp/npacks
drop if price==0

gen ppromotion = promcode!="0000"

collapse (mean) price ppromotion,by(prodcode month)

gen promotion = ppromotion>0.5

keep prodcode month promotion

sa "$P/promotion.dta",replace

***Advertising stock (plus square)

u "M:/Advertising/Data/Food.dta",clear

keep if year==2009|year==2010

gen str15 x=""

replace x = "anchor"       if index(lower(Brand),"anchor")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0| index(lower(Brand),"margarine")>0)
replace x = "arla"         if index(lower(Brand),"arla foods - butter")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0| index(lower(Brand),"margarine")>0)
replace x = "bertolli"     if index(lower(Brand),"bertolli")>0 & index(lower(Brand),"spread")>0
replace x = "bertolli"     if index(lower(Brand),"olivio")>0 & index(lower(Brand),"spread")>0
replace x = "clover"       if index(lower(Brand),"clover")>0 & index(lower(Brand),"spread")>0
replace x = "country life" if index(lower(Brand),"country life")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "dairy"        if index(lower(Brand),"dairy crest")>0
replace x = "flora"        if index(lower(Brand),"flora")>0
replace x = "cant"         if index(lower(Brand),"i cant")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "gold"         if index(lower(Brand),"st ivel - gold")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "gold"         if index(lower(Brand),"st ivel gold")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "hollybush"    if index(lower(Brand),"hollybush")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "kerrygold"    if index(lower(Brand),"kerrygold")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "lidl"         if index(lower(Brand),"lidl")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "lurpak"       if index(lower(Brand),"lurpak")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "netto"        if index(lower(Brand),"netto")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "president"    if index(lower(Brand),"president")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "pure"         if index(lower(Brand),"pure")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "utterly"      if index(lower(Brand),"st ivel - utterly")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "stork"        if index(lower(Brand),"stork")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "st ivel"      if index(lower(Brand),"st ivel")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "unilever"     if index(lower(Brand),"unilever")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "vitalite"     if index(lower(Brand),"vitalite")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "what not"     if index(lower(Brand),"what not")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "willow"       if index(lower(Brand),"willow")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "yeo"          if index(lower(Brand),"yeo")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)
replace x = "yorkshire"    if index(lower(Brand),"yorkshire")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0)

replace x = "aldi"         if index(lower(Brand),"aldi")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0| index(lower(Brand),"margarine")>0)
replace x = "asda"         if index(lower(Brand),"asda")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "co-op"        if index(lower(Brand),"co-op")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "morrisons"    if index(lower(Brand),"morrisons")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "sainsbury"    if index(lower(Brand),"sainsbury")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "somerfield"   if index(lower(Brand),"somerfield")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "tesco"        if index(lower(Brand),"tesco")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""
replace x = "waitrose"     if index(lower(Brand),"waitrose")>0 & (index(lower(Brand),"butter")>0 | index(lower(Brand),"spread")>0  | index(lower(Brand),"margarine")>0) & x==""

foreach var in "arla" "anchor" "bertolli" "clover" "country life" "dairy" "flora" "cant" "gold" "hollybush" "kerrygold" "lidl" "lurpak" "netto" "president" "pure" "utterly" "stork" "st ivel" "unilever" "vitalite" "what not" "willow" "yeo" "yorkshire" "aldi" "asda" "co-op" "morrisons" "sainsbury" "somerfield" "tesco" "waitrose" "other" {
    tab Brand if x=="`var'"
}

gen     add_brand = "Anchor Butter" if Brand=="Anchor - Butter"|Brand=="Anchor - Free Rge Butter"
replace add_brand = "Anchor Spreadable Lighter" if Brand=="Anchor - Lighter Spreadable"
replace add_brand = "Anchor Spreadable" if Brand=="Anchor - Spreadable Butter"

replace add_brand = "Bertolli(Unilever)Spread" if Brand=="Bertolli - Spread"
replace add_brand = "Bertolli Light Olive Sprd" if Brand=="Bertolli - Light Spread"

replace add_brand = "Clover Std Dairy Spread" if Brand=="Dairy Crest - Clover Spread" | Brand=="Dairy Crest - Clover Range"
replace add_brand = "Clover Diet Low Fat Sprd" if Brand=="Dairy Crest - Clover Lighter"

replace add_brand = "Country Life Butter" if Brand=="Country Life - English Butter"| Brand=="Country Life - Butter Rge"
replace add_brand = "Country Life Light Sprdbl" if Brand=="Country Life - Lighter Spreadable"
replace add_brand = "Country Life Spreadable" if Brand=="Country Life - Spreadable Butter"

replace add_brand = "Dairy Crest" if Brand=="Dairy Crest -  Generic"

replace add_brand = "Flora Buttery" if Brand=="Flora - Buttery Spread"
replace add_brand = "Flora Extra Light Spread" if Brand=="Flora - Extra Light Margarine"
replace add_brand = "Flora Light Spread" if Brand=="Flora - Light Margarine"
replace add_brand = "Flora Pro Activ Lght Spd" if Brand=="Flora - Pro Activ Rge"| Brand=="Flora - Pro Activ Spread" | Brand=="Flora - Pro Activ Buttery Spread" | Brand=="Flora - Pro Activ Light Spread"

replace add_brand = "Flora" if Brand=="Flora - Generic" | Brand=="Flora - Margarine" | Brand=="Flora - Margarine Range"| Brand=="Flora - London Marathon"

replace add_brand = "I C B I N B Dairy Spd" if Brand=="I Cant Believe Its Not Butter - Spr"
replace add_brand = "I C B I N B Lght Dry Sprd" if Brand=="I Cant Believe Its Not Butter Light"

replace add_brand = "Kerrygold Butter" if Brand=="Kerrygold - Butter"| Brand=="Kerrygold - Frozen Butter Portions"| Brand=="Kerrygold - Light Butter" | Brand=="Kerrygold - Softer Butter" | Brand=="Kerrygold - Spreadable Butter"

replace add_brand = "Lurpak Butter" if Brand=="Arla Foods - Lurpak Butter Rge"
replace add_brand = "Lurpak Spreadable" if Brand=="Arla - Lurpak Spreadable Unsalted"
replace add_brand = "Lurpak Spreadable Lighter" if Brand=="Arla Foods - Lurpak Spreadable"

replace add_brand = "St Ivel Utrly Bttrly D/Sp" if Brand=="St Ivel - Utterly Butterly"

replace add_brand = "Stork Packet Margarine" if Brand=="Stork - Margarine"

replace add_brand = "Unilever" if Brand=="Unilever - Margarine Rge" | Brand=="Unilever - Spread Rge" | Brand=="Unilever Uk - Margarine Generic"

replace add_brand = "Morrs Vl Butter" if Brand==" Morrisons - Value Butter"

replace add_brand = "Flora Pufa" if month==1 & add_brand==""
replace add_brand = "Vitalite Pufa" if month==2 & add_brand==""
replace add_brand = "Willow Dairy Spread" if month==3 & add_brand==""
replace exp = 0 if add_brand=="Flora Pufa" | add_brand=="Vitalite Pufa" | add_brand=="Willow Dairy Spread"

drop if add_brand==""

collapse (sum) exp,by(year month add_brand)

fillin year month add_brand
replace exp = 0 if exp==.
drop _f

gen x = exp if add_brand=="Unilever"
egen xx = sum(x),by(month)
replace exp = exp+xx if add_brand=="Bertolli Light Olive Sprd" | add_brand=="Bertolli(Unilever)Spread" | add_brand=="Flora Buttery" | add_brand=="Flora Light Spread" | add_brand=="Flora Pro Activ Lght Spd" | add_brand=="I C B I N B Dairy Spd" | add_brand=="Stork Packet Margarine"| add_brand=="Flora Pufa"
drop x xx

gen x = exp if add_brand=="Flora"
egen xx = sum(x),by(month)
replace exp = exp+xx if add_brand=="Flora Buttery" | add_brand=="Flora Light Spread" | add_brand=="Flora Pro Activ Lght Spd" | add_brand=="Flora Pufa"
drop x xx

gen x = exp if add_brand=="Dairy Crest"
egen xx = sum(x),by(month)
replace exp = exp+xx if add_brand=="Clover Diet Low Fat Sprd" | add_brand=="Clover Std Dairy Spread" | add_brand=="Country Life Butter" | add_brand=="Country Life Light Sprdbl" | add_brand=="Country Life Spreadable" | add_brand=="St Ivel Utrly Bttrly D/Sp" | add_brand=="Vitalite Pufa" | add_brand=="Willow Dairy Spread"
drop x xx

drop if add_brand=="Unilever"|add_brand=="Flora"|add_brand=="Dairy Crest"

sa "$P/ad_flow.dta",replace

u "$P/ad_flow.dta",clear

sort add_brand year month

by add_brand: gen N = _N
by add_brand: gen n = _n

gen stock = 0

su N
local l = r(mean)-1

foreach v of numlist 0(1)`l' {

    gen NN = N-n-`v'
    gen     temp1 = exp*(0.75^NN)
    replace temp1 = . if NN<0
    egen    temp2 = sum(temp1),by(add_brand)
    replace stock = temp2 if NN==0
    drop NN temp1 temp2
}
drop n N

replace stock = stock/100000

keep year month add_brand stock exp
rename exp adexp

sa "$P/ad_stock.dta",replace

***Additional household variables (size, income dummies, work status, equivalence scale)

u "M:\TNS\extractedfiles\panel_data\hhpanel_all.dta",clear

merge m:1 hhno using "$P/temp.dta"
drop if _m==1
drop _m

sort hhno demyear
by hhno: replace hhinc = hhinc[_n-1] if hhinc==.
by hhno: replace hhinc = hhinc[_n+1] if hhinc==.
egen m_hhinc = mean(hhinc),by(hhno)
replace hhinc = m_hhinc if hhinc==.

by hhno: replace bmi_group = bmi_group[_n-1] if bmi_group==.
egen m_bmi_group = mean(bmi_group),by(hhno)
replace bmi_group = m_bmi_group if bmi_group==.

by hhno: replace msempstat  = msempstat[_n-1]  if msempstat==0
by hhno: replace hohempstat = hohempstat[_n-1] if hohempstat==0

keep if demyear==2010

*Household specific fix
replace ageper1=50 if hhno==53883
replace ageper2=57 if hhno==53883
replace ageper3=28 if hhno==53883
replace ageper4=27 if hhno==53883
replace ageper5=26 if hhno==53883
replace ageper6=24 if hhno==53883
replace ageper7=22 if hhno==53883
replace ageper8=19 if hhno==53883

replace ageper1=63 if hhno==142104
replace ageper2=62 if hhno==142104

replace ageper1=72 if hhno==162734

replace ageper1=71 if hhno==190045
replace ageper2=59 if hhno==190045
replace ageper3=59 if hhno==190045

rename msage age
rename mssex sex

gen nkids0_13=0
gen nkids14_18=0
gen nad=0
foreach n of numlist 1(1)12 {
   replace nkids0_13=nkids0_13+1 if ageper`n'<=13
   replace nkids14_18=nkids14_18+1 if ageper`n'>=14&ageper`n'<=18
   replace nad=nad+1 if ageper`n'>18&ageper`n'<.
}

gen numeqads=(0.67+(nad-1)*0.33)/0.67
gen numeqkids=(0.2*nkids0_13+0.33*nkids14_18)/0.67
gen hheqsize = numeqads+numeqkids


keep hhno hhinc bmi_group hhsize msempstat hohempstat hheqsize

gen     labour = 1 if msempstat==1 & hohempstat==1 & hhsize>1
replace labour = 1 if msempstat==1 & hhsize==1
replace labour = 2 if msempstat==1 & hohempstat>1 & hhsize>1
replace labour = 2 if msempstat>1 & hohempstat==1 & hhsize>1
replace labour = 3 if msempstat!=1 & msempstat!=6 & hohempstat!=1 & hhsize>1
replace labour = 3 if msempstat!=1 & hohempstat!=1 & hohempstat!=6 & hhsize>1
replace labour = 3 if msempstat!=1 & msempstat!=6 & hhsize==1
replace labour = 4 if msempstat==6 & hohempstat==6 & hhsize>1
replace labour = 4 if msempstat==6 & hhsize==1

lab def labour 1 "Full time working household" 2 "One member full work" 3 "Non full time working household" 4 "Retired household"
lab val labour labour

gen     income = 0 if hhinc==0
replace income = 1 if hhinc==1|hhinc==2
replace income = 2 if hhinc==3|hhinc==4
replace income = 3 if hhinc>4

lab def income 0 "Unknown" 1 "<20k" 2 "20k-40k" 3 "40k+"
lab val income income

gen     temp = 5000  if hhinc==1
replace temp = 15000 if hhinc==2
replace temp = 25000 if hhinc==3
replace temp = 35000 if hhinc==4
replace temp = 45000 if hhinc==5
replace temp = 55000 if hhinc==6
replace temp = 65000 if hhinc==7
replace temp = 75000 if hhinc==8

gen temp_eq = temp/hheqsize
centile temp_eq,centile(25 50 75)
gen     income_eq = 1 if              temp_eq<r(c_1)
replace income_eq = 2 if temp_eq>=r(c_1)&temp_eq<r(c_2)
replace income_eq = 3 if temp_eq>=r(c_2)&temp_eq<r(c_3)
replace income_eq = 4 if temp_eq>=r(c_3)&temp_eq<.
replace income_eq = 0 if hhincome==0
drop temp_eq

lab def income_eq 0 "Unknown" 1 "1st q" 2 "2nd q" 3 "3rd q" 4 "4th q"
lab val income_eq income_eq

gen     hhmember = hhsize
replace hhmember = 5 if hhsize>5

keep hhno labour hhmember hheqsize income income_eq hhinc

sa "$P/demogs_ex.dta",replace

***Add additional variables to data and outsheet

u "$P/pre_matlab.dta",clear

merge m:1 hhno using "$P/household_info.dta",keepusing(weight obese hhsize)
drop _m

merge m:1 hhno using "$P/demogs_ex.dta"
keep if _m==3
drop _m

merge m:1 hhno using "$P/net_expenditure_foodt.dta"
keep if _m==3
drop _m

gen year = 2010

decode brand,g(add_brand)
merge m:1 add_brand year month using "$P/ad_stock.dta"
drop if _m==2
replace adexp = 0 if _m==1
replace stock = 0 if _m==1
drop _m
rename stock ad_stock
gen ad_stock_2 = ad_stock^2

merge m:1 prodcode month using "$P/promotion.dta"
replace promotion = 0 if prodcode==999999
drop _m

gen netexp = exp-price

gen netexp2 = netexp^2
gen netexp3 = netexp^3

gen size500_hhsize  = size500*hhsize
gen size1000_hhsize = size1000*hhsize

gen size500_obese  = size500*obese
gen size1000_obese = size1000*obese

gen sats_obese  = saturates*obese

gen but_obese = but*obese

gen volsat = 0
replace volsat = saturates*2.5 if size250==1
replace volsat = saturates*5   if size500==1
replace volsat = saturates*10  if size1000==1

foreach n of numlist 0(1)8 {
    gen price_inc`n' = price if hhinc==`n'
    replace price_inc`n' = 0 if price_inc`n'==.
}

keep  choicesituation hh prod weight month choice price netexp netexp2 netexp3 but adexp size500 size1000 size500_hhsize size1000_hhsize size500_obese size1000_obese sats_obese but_obese zz2-zz33 volsat promotion ad_stock ad_stock_2 price_inc0-price_inc8 hhmember labour hhinc hheqsize
order choicesituation hh prod weight month choice price netexp netexp2 netexp3 but adexp size500 size1000 size500_hhsize size1000_hhsize size500_obese size1000_obese sats_obese but_obese zz2-zz33 volsat promotion ad_stock ad_stock_2 price_inc0-price_inc8 hhmember labour hhinc hheqsize

lab var choicesituation "Choice situation"
lab var hh              "Household index"
lab var prod            "Product index"
lab var weight          "Household weight"
lab var month           "Month"
lab var choice          "Choice=1"
lab var price           "Price"
lab var netexp          "y-p"
lab var netexp2         "(y-p)^2"
lab var netexp3         "(y-p)^3"
lab var but             "Butter"
lab var adexp           "This month's ad exp (m)"
lab var size500         "Pack size 500g"
lab var size1000        "Pack size 1Kg"
lab var volsat          "Volume of saturates (for tax)"
lab var promotion       "=1 if >50% of transaction on promotion"
lab var ad_stock        "Ad stock (memory = 0.75)"
lab var hhmember        "Number of household members - topcoded"
lab var labour          "HH labour market status"
lab var hhincome        "Household income"
lab var hheqsize        "Equivalence scale"

so choicesituation choice prod
sa "$P\data.dta",replace

outsheet using "$P\data.raw", replace comma nol

log close

log using "$P\data_desc.log",replace

desc

log close

**************************************************************************
**Create ownership file
**************************************************************************

u "$P/pre_matlab.dta",clear

bysort prod manu: keep if _n==1
tab manu,gen(mm)

egen brd = group(manu brand)

keep  prod brd manu mm*
order prod brd manu mm*

outsheet using "$P\ownership.raw", replace comma nol non


