clear all
set more off
cap log close

***Data directories

global Path "C:/GriffithNesheimOConnell.2017.QE"

global O "$Path\MatLab_files"

global ON "$O\Nonlinear"
global OL "$O\Linear"
global OP "$O\Prefshift"
global OA "$O\Linearized"

global OLN  "$O\Log"
global OLN2 "$O\Logcubic"

global D "$Path\Stata_files\Results"

global DN "$D\Nonlinear"
global DL "$D\Linear"
global DP "$D\Prefshift"
global DA "$D\Linearized"

global D "$Path\Stata_files\MOut"

global B "$Path\Stata_files\Bootstrap"

global BN "$B\Nonlinear"
global BL "$B\Linear"
global BP "$B\Prefshift"
global BA "$B\Linearized"

global G "$Path\Stata_files\Tables"
global P "$Path\Stata_files/All"
global C "$Path\Stata_files\Estimation"

global Do "$Path\Programmes\Results"


***Preliminary files

u "$C/pre_matlab.dta",clear

bysort hhno: keep if _n==1
keep hhno hh

merge m:1 hhno using "$C/net_expenditure_foodt.dta"
keep if _m==3
drop _m

merge m:1 hhno using "$C/demogs_ex.dta",keepusing(hhmember)
keep if _m==3
drop _m

sa "$P/hh_exp.dta",replace

***Coefficient estimates
**Polynomial model

insheet using "$M/coefs_Nonlinear.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 2  if variable=="p2"
replace var = 3  if variable=="p3"
replace var = 4  if variable=="hhsize2_p1"
replace var = 5  if variable=="hhsize2_p2"
replace var = 6  if variable=="hhsize2_p3"
replace var = 7  if variable=="hhsize3_p1"
replace var = 8  if variable=="hhsize3_p2"
replace var = 9  if variable=="hhsize3_p3"
replace var = 10 if variable=="hhsize4_p1"
replace var = 11 if variable=="hhsize4_p2"
replace var = 12 if variable=="hhsize4_p3"
replace var = 13 if variable=="hhsize5_p1"
replace var = 14 if variable=="hhsize5_p2"
replace var = 15 if variable=="hhsize5_p3"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

foreach v in coefficient standard_error {
    replace `v'=`v'*10    if variable=="p1"|variable=="but_p1_cov"|variable=="hhsize2_p1"|variable=="hhsize3_p1"|variable=="hhsize4_p1"|variable=="hhsize5_p1"
    replace `v'=`v'*100   if variable=="p2"|variable=="p1_sig2"|variable=="hhsize2_p2"|variable=="hhsize3_p2"|variable=="hhsize4_p2"|variable=="hhsize5_p2"
    replace `v'=`v'*1000  if variable=="p3"|variable=="hhsize2_p3"|variable=="hhsize3_p3"|variable=="hhsize4_p3"|variable=="hhsize5_p3"
}

drop variable

sa "$P/cubic_coefficients.dta",replace

insheet using "$M/coefs_Linear.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 4  if variable=="hhsize2_p1"
replace var = 7  if variable=="hhsize3_p1"
replace var = 10 if variable=="hhsize4_p1"
replace var = 13 if variable=="hhsize5_p1"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

foreach v in coefficient standard_error {
    replace `v'=`v'*10    if variable=="p1"|variable=="but_p1_cov"|variable=="hhsize2_p1"|variable=="hhsize3_p1"|variable=="hhsize4_p1"|variable=="hhsize5_p1"
    replace `v'=`v'*100   if variable=="p2"|variable=="p1_sig2"|variable=="hhsize2_p2"|variable=="hhsize3_p2"|variable=="hhsize4_p2"|variable=="hhsize5_p2"
    replace `v'=`v'*1000  if variable=="p3"|variable=="hhsize2_p3"|variable=="hhsize3_p3"|variable=="hhsize4_p3"|variable=="hhsize5_p3"
}

rename coefficient    coefficient_l
rename standard_error standard_error_l

drop variable

merge 1:1 var using "$P/cubic_coefficients.dta"
drop _m

lab def vp 1  "(y-p)" 2  "(y-p)\textsuperscript{2}" 3  "(y-p)\textsuperscript{3}" 4  "(y-p)*hh2" 5  "(y-p)\textsuperscript{2}*hh2" 6  "(y-p)\textsuperscript{3}*hh2" 7  "(y-p)*hh3" 8  "(y-p)\textsuperscript{2}*hh3" 9  "(y-p)\textsuperscript{3}*hh3" 10 "(y-p)*hh4" 11 "(y-p)\textsuperscript{2}*hh4" 12 "(y-p)\textsuperscript{3}*hh4" 13 "(y-p)*hh5" 14 "(y-p)\textsuperscript{2}*hh5" 15 "(y-p)\textsuperscript{3}*hh5" 16 "Var(y-p)" 17 "Var(Butter)" 18 "Cov(y-p, Butter)" 19 "Promotion" 20 "Advertising" 21 "Advertising\textsuperscript{2}" 22 "500g" 23 "1kg" 24 "500g*Household size" 25 "1kg*Household size" 26 "No purchase*Mixed work" 27 "No purchase*Non full time" 28 "No purchase*Retired" 29 "No purchase*hh2" 30 "No purchase*hh3" 31 "No purchase*hh4" 32 "No purchase*hh5"
lab val var vp

**Table 4.3 and Appendix A

tabout var using "$G/coeff1_poly.tex" if var<4,         replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff2_poly.tex" if var>3&var<16,  replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff3_poly.tex" if var>15&var<19, replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff4_poly.tex" if var>18,        replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)

**Log model

insheet using "$M/coefs_Cublog.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 2  if variable=="p2"
replace var = 3  if variable=="p3"
replace var = 4  if variable=="hhsize2_p1"
replace var = 5  if variable=="hhsize2_p2"
replace var = 6  if variable=="hhsize2_p3"
replace var = 7  if variable=="hhsize3_p1"
replace var = 8  if variable=="hhsize3_p2"
replace var = 9  if variable=="hhsize3_p3"
replace var = 10 if variable=="hhsize4_p1"
replace var = 11 if variable=="hhsize4_p2"
replace var = 12 if variable=="hhsize4_p3"
replace var = 13 if variable=="hhsize5_p1"
replace var = 14 if variable=="hhsize5_p2"
replace var = 15 if variable=="hhsize5_p3"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

drop variable

sa "$P/logcubic_coefficients.dta",replace

insheet using "$M/coefs_Log.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 4  if variable=="hhsize2_p1"
replace var = 7  if variable=="hhsize3_p1"
replace var = 10 if variable=="hhsize4_p1"
replace var = 13 if variable=="hhsize5_p1"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

rename coefficient    coefficient_l
rename standard_error standard_error_l

drop variable

merge 1:1 var using "$P/logcubic_coefficients.dta"
drop _m

lab def vl 1  "ln(y-p)" 2  "ln(y-p)\textsuperscript{2}" 3  "ln(y-p)\textsuperscript{3}" 4  "ln(y-p)*hh2" 5  "ln(y-p)\textsuperscript{2}*hh2" 6  "ln(y-p)\textsuperscript{3}*hh2" 7  "ln(y-p)*hh3" 8  "ln(y-p)\textsuperscript{2}*hh3" 9  "ln(y-p)\textsuperscript{3}*hh3" 10 "ln(y-p)*hh4" 11 "ln(y-p)\textsuperscript{2}*hh4" 12 "ln(y-p)\textsuperscript{3}*hh4" 13 "ln(y-p)*hh5" 14 "ln(y-p)\textsuperscript{2}*hh5" 15 "ln(y-p)\textsuperscript{3}*hh5" 16 "Var(ln(y-p))" 17 "Var(Butter)" 18 "Cov(ln(y-p), Butter)" 19 "Promotion" 20 "Advertising" 21 "Advertising\textsuperscript{2}" 22 "500g" 23 "1kg" 24 "500g*Household size" 25 "1kg*Household size" 26 "No purchase*Mixed work" 27 "No purchase*Non full time" 28 "No purchase*Retired" 29 "No purchase*hh2" 30 "No purchase*hh3" 31 "No purchase*hh4" 32 "No purchase*hh5"
lab val var vl

**Appendix A

tabout var using "$G/coeff1_log.tex" if var<4,         replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff2_log.tex" if var>3&var<16,  replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff3_log.tex" if var>15&var<19, replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff4_log.tex" if var>18,        replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_l mean standard_error_l mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)

**Preference shifter model

insheet using "$M/coefs_Linearized.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 2  if variable=="grossexp_p1"
replace var = 3  if variable=="grossexp2_p1"
replace var = 4  if variable=="hhsize2_p1"
replace var = 5  if variable=="grossexp_hhsize2_p1"
replace var = 6  if variable=="grossexp2_hhsize2_p1"
replace var = 7  if variable=="hhsize3_p1"
replace var = 8  if variable=="grossexp_hhsize3_p1"
replace var = 9  if variable=="grossexp2_hhsize3_p1"
replace var = 10 if variable=="hhsize4_p1"
replace var = 11 if variable=="grossexp_hhsize4_p1"
replace var = 12 if variable=="grossexp2_hhsize4_p1"
replace var = 13 if variable=="hhsize5_p1"
replace var = 14 if variable=="grossexp_hhsize5_p1"
replace var = 15 if variable=="grossexp2_hhsize5_p1"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

foreach v in coefficient standard_error {
    replace `v'=`v'*10    if variable=="grossexp_p1"|variable=="grossexp_hhsize2_p1"|variable=="grossexp_hhsize3_p1"|variable=="grossexp_hhsize4_p1"|variable=="grossexp_hhsize5_p1"
    replace `v'=`v'*100   if variable=="grossexp2_p1"|variable=="grossexp2_hhsize2_p1"|variable=="grossexp2_hhsize3_p1"|variable=="grossexp2_hhsize4_p1"|variable=="grossexp2_hhsize5_p1"
}

drop variable

sa "$P/linearized_coefficients.dta",replace

insheet using "$M/coefs_Prefshift.raw",clear

rename v1 variable
rename v2 coefficient
rename v3 standard_error

gen     var = 1  if variable=="p1"
replace var = 2  if variable=="grossexp_p1"
replace var = 4  if variable=="hhsize2_p1"
replace var = 5  if variable=="grossexp_hhsize2_p1"
replace var = 7  if variable=="hhsize3_p1"
replace var = 8  if variable=="grossexp_hhsize3_p1"
replace var = 10 if variable=="hhsize4_p1"
replace var = 11 if variable=="grossexp_hhsize4_p1"
replace var = 13 if variable=="hhsize5_p1"
replace var = 14 if variable=="grossexp_hhsize5_p1"
replace var = 16 if variable=="p1_sig2"
replace var = 17 if variable=="but_p1_cov"
replace var = 18 if variable=="but_sig2"
replace var = 19 if variable=="promotion"
replace var = 20 if variable=="ad_stock"
replace var = 21 if variable=="ad_stock_2"
replace var = 22 if variable=="size500"
replace var = 23 if variable=="size1000"
replace var = 24 if variable=="size500_hhsize"
replace var = 25 if variable=="size1000_hhsize"
replace var = 26 if variable=="zz1_labour2"
replace var = 27 if variable=="zz1_labour3"
replace var = 28 if variable=="zz1_labour4"
replace var = 29 if variable=="zz1_hhsize2"
replace var = 30 if variable=="zz1_hhsize3"
replace var = 31 if variable=="zz1_hhsize4"
replace var = 32 if variable=="zz1_hhsize5"

foreach v in coefficient standard_error {
    replace `v'=`v'*10    if variable=="grossexp_p1"|variable=="grossexp_hhsize2_p1"|variable=="grossexp_hhsize3_p1"|variable=="grossexp_hhsize4_p1"|variable=="grossexp_hhsize5_p1"
    replace `v'=`v'*100   if variable=="grossexp2_p1"|variable=="grossexp2_hhsize2_p1"|variable=="grossexp2_hhsize3_p1"|variable=="grossexp2_hhsize4_p1"|variable=="grossexp2_hhsize5_p1"
}

rename coefficient    coefficient_p
rename standard_error standard_error_p

drop variable

merge 1:1 var using "$P/linearized_coefficients.dta"
drop _m

lab def vps 1  "p" 2  "p*y" 3  "p*y\textsuperscript{2}" 4  "p*hh2" 5  "p*y*hh2" 6  "p*y\textsuperscript{2}*hh2" 7  "p*hh3" 8  "p*y*hh3" 9  "p*y\textsuperscript{2}*hh3" 10 "p*hh4" 11 "p*y*hh4" 12 "p*y\textsuperscript{2}*hh4" 13 "p*hh5" 14 "p*y*hh5" 15 "p*y\textsuperscript{2}*hh5" 16 "Var(p)" 17 "Var(Butter)" 18 "Cov(p, Butter)" 19 "Promotion" 20 "Advertising" 21 "Advertising\textsuperscript{2}" 22 "500g" 23 "1kg" 24 "500g*Household size" 25 "1kg*Household size" 26 "No purchase*Mixed work" 27 "No purchase*Non full time" 28 "No purchase*Retired" 29 "No purchase*hh2" 30 "No purchase*hh3" 31 "No purchase*hh4" 32 "No purchase*hh5"
lab val var vps

**Appendix A

tabout var using "$G/coeff1_lin.tex" if var<4,         replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_p mean standard_error_p mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff2_lin.tex" if var>3&var<16,  replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_p mean standard_error_p mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff3_lin.tex" if var>15&var<19, replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_p mean standard_error_p mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)
tabout var using "$G/coeff4_lin.tex" if var>18,        replace sum bt ptotal(none) format(4 4 4 4)  cells(mean coefficient_p mean standard_error_p mean coefficient mean standard_error mean) style(tex) h1(nil) h2(nil) h3(nil)

***Marginal utility of expenditure

u "$P/hh_exp.dta",clear

***By household size
foreach n of numlist 1(1)5 {

    centile exp if hhm==`n',centile(2.5 97.5)
    gen ch`n'l = r(c_1)
    gen ch`n'u = r(c_2)

}

gen MU_c1 = 3.048373+-0.022973*2*exp+0.000119 *3*(exp^2)
gen MU_c2 = 3.586442+-0.028428*2*exp+0.000152*3*(exp^2)
gen MU_c3 = 3.498596+-0.018027*2*exp+0.000062*3*(exp^2)
gen MU_c4 = 4.000518+-0.021086*2*exp+0.000081*3*(exp^2)
gen MU_c5 = 5.535379+-0.041082*2*exp+0.000198 *3*(exp^2)

gen MU_ln1 = 2.111944
gen MU_ln2 = 2.096627
gen MU_ln3 = 2.236457
gen MU_ln4 = 2.526425
gen MU_ln5 = 2.927042

gen MU_lg1 = 36.0098/exp
gen MU_lg2 = 5.0112/exp +MU_lg1
gen MU_lg3 = 13.3274/exp+MU_lg1
gen MU_lg4 = 27.2697/exp+MU_lg1
gen MU_lg5 = 49.1824/exp+MU_lg1

gen MU_lgc1 = (1/exp)*(220.0412+-61.2514*ln(exp)*2+7.4094*(ln(exp)^2)*3)
gen MU_lgc2 = (1/exp)*(14.3735+-2.5404*ln(exp)*2+0.2404*(ln(exp)^2)*3)	 +MU_lgc1
gen MU_lgc3 = (1/exp)*(-111.8476+33.0628*ln(exp)*2+-2.8514*(ln(exp)^2)*3)+MU_lgc1
gen MU_lgc4 = (1/exp)*(10.9113+-4.1598*ln(exp)*2+1.2143*(ln(exp)^2)*3)	 +MU_lgc1
gen MU_lgc5 = (1/exp)*(221.7783+-63.1248*ln(exp)*2+7.1645*(ln(exp)^2)*3) +MU_lgc1

**Figure 4.4
sort exp
line MU_c1 exp if exp>ch1l & exp<ch1u,lcolor(black) || line MU_c2 exp if exp>ch2l & exp<ch2u,lcolor(gs3) || line MU_c3 exp if exp>ch3l & exp<ch3u,lcolor(gs6) || line MU_c4 exp if exp>ch4l & exp<ch4u,lcolor(gs9) || line MU_c5 exp if exp>ch5l & exp<ch5u, lcolor(gs12) xtitle("Mean weekly grocery expenditure ()") ytitle("Mean conditional marginal" "utility of grocery expenditure") graphr(color(white)) bgcolor(white)  title("") legend(title("Household size",color(black) size(medium)) lab(1 "1") lab(2 "2") lab(3 "3") lab(4 "4") lab(5 "5+") rows(2))
graph export "$G/mu_cubic.png",replace

**Figure 4.5
sort exp
line MU_ln2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(shortdash) || line MU_c2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(solid) || line MU_P4_2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(...-) || line MU_P5_2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(-) ,xtitle("y-p ()") ytitle("Mean conditional marginal" "utility of grocery expenditure") graphr(color(white)) bgcolor(white) legend(lab(1 "Linear utility") lab(2 "Cubic utility") lab(3 "Quartic utility") lab(4 "Quintic utility") order(1 2 3 4))
graph export "$G/mu_polynomial_hh2.png",replace
line MU_lg2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(-) || line MU_lgc2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(...-) || line MU_c2 exp if exp>ch2l & exp<ch2u,lcolor(black) lpattern(solid) xtitle("y-p ()") ytitle("Mean conditional marginal" "utility of grocery expenditure") graphr(color(white)) bgcolor(white) legend(lab(1 "Log utility") lab(2 "Log-cubic utility") lab(3 "Cubic utility") order(1 2 3))
graph export "$G/mu_hh`n'_g3.png",replace


***Variation in elasticities with expenditure

**Prepare file

insheet using "$M/oelas_linear.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

collapse (sum) elas,by(hh)

rename elas linear_elas

sa "$P/linear_elas.dta",replace

insheet using "$M/oelas_prefshift.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

collapse (sum) elas,by(hh)

rename elas prefshift_elas

sa "$P/prefshift_elas.dta",replace

insheet using "$M/oelas_linearized.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

collapse (sum) elas,by(hh)

rename elas linearized_elas

sa "$P/linearized_elas.dta",replace

insheet using "$M/oelas_log.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

collapse (sum) elas,by(hh)

rename elas log_elas

sa "$P/log_elas.dta",replace

insheet using "$M/oelas_logcubic.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

collapse (sum) elas,by(hh)

rename elas logcubic_elas

sa "$P/logcubic_elas.dta",replace

insheet using "$M/oelas_cubic.raw",clear

rename v1 hh
rename v2 product
rename v3 elas
rename v4 share
drop v5

drop if product==1
egen sum = sum(share),by(hh)
replace share=share/sum

replace elas = elas*share

merge m:1 hh using "$P/hh_exp.dta"
keep if _m==3
drop _m

collapse (sum) elas (mean) exp,by(hh hhm)

rename elas cubic_elas

sa "$P/cubic_elas.dta",replace

merge 1:1 hh using "$P/linear_elas.dta"
drop _m
merge 1:1 hh using "$P/prefshift_elas.dta"
drop _m
merge 1:1 hh using "$P/linearized_elas.dta"
drop _m
merge 1:1 hh using "$P/log_elas.dta"
drop _m
merge 1:1 hh using "$P/logcubic_elas.dta"
drop _m

sa "$P/all_elas.dta",replace

**Graphs

u "$P/all_elas.dta",clear

centile exp if hhm==2,centile(2.5 97.5)
gen ch2l = r(c_1)
gen ch2u = r(c_2)

lpoly cubic_elas       exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(cx_1 cy_1)
lpoly linear_elas      exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(lx_1 ly_1)
lpoly prefshift_elas   exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(px_1 py_1)
lpoly linearized_elas  exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(ax_1 ay_1)
lpoly log_elas         exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(lgx_1 lgy_1)
lpoly logcubic_elas    exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(lgcx_1 lgcy_1)

**Figure 4.6
line cy_1 cx_1,lcolor(black) || line ly_1 lx_1,lcolor(black)  lpattern(-) || line py_1 px_1,lcolor(black) lpattern(_)  graphr(color(white)) bgcolor(white)  xtitle("Mean weekly grocery expenditure (s)") ytitle("Mean own price elasticity") legend(lab(1 "Cubic utility") lab(2 "Linear utility") lab(3 "Preference shifter"))
graph export "$G/elas_hh2_g1.png",replace

do "$Do/Elas_tables.do"

***Variation in compensating variation with expenditure

**Graphs

u "$DL/cv_multi_ex.dta",clear
merge 1:1 hhno using "$DL/cv_multi_ad.dta"
drop _m

keep hhno CV_nashmultiex_m2 CV_nashmultiad_m2

merge 1:1 hhno using "$DL/hhweights.dta"
drop _m

foreach v in CV_nashmultiex_m2 CV_nashmultiad_m2 {
    replace `v'=`v'*tripweight
}
drop tripweight demweight

rename CV_nashmultiex_m2 linear_ex
rename CV_nashmultiad_m2 linear_ad

rename hhno hh

sa "$P/linear_cv.dta",replace

u "$DP/cv_multi_ex.dta",clear
merge 1:1 hhno using "$DP/cv_multi_ad.dta"
drop _m

keep hhno CV_nashmultiex_m2 CV_nashmultiad_m2

merge 1:1 hhno using "$DL/hhweights.dta"
drop _m

foreach v in CV_nashmultiex_m2 CV_nashmultiad_m2 {
    replace `v'=`v'*tripweight
}
drop tripweight demweight

rename CV_nashmultiex_m2 prefshift_ex
rename CV_nashmultiad_m2 prefshift_ad

rename hhno hh

sa "$P/prefshift_cv.dta",replace

u "$DA/cv_multi_ex.dta",clear
merge 1:1 hhno using "$DA/cv_multi_ad.dta"
drop _m

keep hhno CV_nashmultiex_m2 CV_nashmultiad_m2

merge 1:1 hhno using "$DL/hhweights.dta"
drop _m

foreach v in CV_nashmultiex_m2 CV_nashmultiad_m2 {
    replace `v'=`v'*tripweight
}
drop tripweight demweight

rename CV_nashmultiex_m2 linearized_ex
rename CV_nashmultiad_m2 linearized_ad

rename hhno hh

sa "$P/linearized_cv.dta",replace

u "$DN/cv_multi_ex.dta",clear
merge 1:1 hhno using "$DN/cv_multi_ad.dta"
drop _m

keep hhno CV_nashmultiex_m2 CV_nashmultiad_m2

merge 1:1 hhno using "$DN/hhweights.dta"
drop _m

foreach v in CV_nashmultiex_m2 CV_nashmultiad_m2 {
    replace `v'=`v'*tripweight
}
drop tripweight demweight

rename CV_nashmultiex_m2 cubic_ex
rename CV_nashmultiad_m2 cubic_ad

rename hhno hh

merge 1:1 hh using "$P/linear_cv.dta"
drop _m
merge 1:1 hh using "$P/prefshift_cv.dta"
drop _m
merge 1:1 hh using "$P/linearized_cv.dta"
drop _m

merge m:1 hh using "$P/hh_exp.dta"
keep if _m==3
drop _m

sa "$P/all_cv.dta",replace

u "$P/all_cv.dta",clear

centile exp if hhm==2,centile(2.5 97.5)
gen ch2l = r(c_1)
gen ch2u = r(c_2)

lpoly cubic_ex  exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(cx_1 cy_1)
lpoly linear_ex exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(lx_1 ly_1)
lpoly prefshift_ex  exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(px_1 py_1)
lpoly linearized_ex exp if hhm==2 & exp>=ch2l & exp<=ch2u,gen(ax_1 ay_1)

**Graph 4.8
line cy_1 cx_1,lcolor(black) || line ly_1 lx_1,lcolor(black)  lpattern(-) || line py_1 px_1,lcolor(black) lpattern(_)  graphr(color(white)) bgcolor(white)  xtitle("Mean weekly grocery expenditure (s)") ytitle("Compensating variation ()") legend(lab(1 "Cubic utility") lab(2 "Linear utility") lab(3 "Preference shifter"))
graph export "$G/CV_hh_g1.png",replace


**CV Tables 

do "$Do/CV_tables.do"


****Aggregate results

u "$DN/aggregate_results.dta",clear

keep if regime=="_advalnoresmulti" | regime=="_advalresmulti" | regime=="_excisenoresmulti" | regime=="_exciseresmulti" | regime=="_pretaxmulti"

keep regime sat exp prof tax CV_m2 wel_m2 tfatcost_m2 cfatcost_m2

xpose,clear varname
drop if _var=="regime"

rename v1 adno
rename v2 adeq
rename v3 exno
rename v4 exeq
rename v5 pre

order pre exno adno exeq adeq

gen     v = 1  if _var=="exp"
replace v = 3  if _var=="prof"
replace v = 5  if _var=="CV_m2"
replace v = 6  if _var=="tax"
replace v = 7  if _var=="wel_m2"
replace v = 8  if _var=="sat"
replace v = 10 if _var=="cfatcost_m2"
replace v = 11 if _var=="tfatcost_m2"
drop if v==.
drop _varname

sort v
order v

sa "$P/agg_res1.dta",replace

u "$P/agg_res1.dta",clear

foreach v in exno adno exeq adeq {
    gen d_`v' = ((`v'-pre)/pre)*100
    drop `v'
    rename d_`v' `v'
}
drop pre
keep if v==1|v==3|v==8
replace v = 2 if v==1
replace v = 4 if v==3
replace v = 9 if v==8

append using "$P/agg_res1.dta"
sort v
order v pre exno adno exeq adeq

lab def v 1 "Expenditure (\pounds m)" 2 "\textit{(% change)}" 3 "Profits (\pounds m)" 4 "\textit{(% change)}" 5 "Compensating variation (\pounds m)" 6 "Tax revenue (\pounds m)" 7 "Welfare (\pounds m)" 8 "Saturated fat (m kg)" 9 "\textit{(% change)}" 10 "Consumer cost per 1kg fat" 11 "Welfare cost per 1kg fat"
lab val v v

**Table 4.8
tabout v using "$G/agg_r1.tex" if v<8      ,replace sum bt ptotal(none) format(2 2 2)  cells(mean pre mean exeq mean adeq) style(tex) h1(nil) h2(nil) h3(nil)
tabout v using "$G/agg_r2.tex" if v>7&v<10  ,replace sum bt ptotal(none) format(2 2 2)  cells(mean pre mean exeq mean adeq) style(tex) h1(nil) h2(nil) h3(nil)
tabout v using "$G/agg_r3.tex" if v>9      ,replace sum bt ptotal(none) format(2 2 2)  cells(mean pre mean exeq mean adeq) style(tex) h1(nil) h2(nil) h3(nil)

**************************************************************************
***Elasticities and costs for appendix
**************************************************************************

**Elasticities

insheet using "$M/melas_cubic.raw",clear

gen prodcode = _n
drop v49
order prodcode

merge 1:1 prodcode using "$DN/product_results.dta"

gen temp = -share_basemulti
egen temp2 = rank(temp)

keep if temp2<12
drop if prodcode==1
keep prodcode v1 v5 v10 v11 v15 v21 v35 v37 v44 v45 v47


cap lab def prod  1 "Outside option" 2   "Kerrygold 250g" 3   "Ar: Anchor 250g" 4   "Ar: Anchor NZ 250g" 5   "Ar: Anchor NZ 500g" 6   "Ar: Anchor light NZ 500g" 7   "Ar: Lurpak ss 250g"   8   "Ar: Lurpak us 250g" 9   "Ar: Lurpak spread ss 250g" 10   "Ar: Lurpak spread ss 500g" 11   "Ar: Lurpak light ss 500g" 12   "Ar: Lurpak light ss 250g" 13   "Asda 250g" 14   "DC: Clover diet 500g" 15   "DC: Clover spread 500g" 16   "DC: Clover spread 1kg" 17   "DC: Country life 250g" 18   "DC: Country life us 250g" 19   "DC: Country life light 500g" 20   "DC: Country life spread 500g" 21   "DC: Utterly Butterly 500g" 22   "DC: Utterly Butterly 1kg" 23   "DC: Vitalite 500g" 24   "DC: Willow 250g" 25   "Sainsburys 250g" 26   "Sainsburys us 250g" 27   "Morrisons 250g" 28   "Tesco butter me up 500g" 29   "Tesco blended 250g" 30   "Tesco value 250g" 31   "Tesco value us 250g" 32   "Un: Bertolli light 500g" 33   "Un: Bertolli 1kg" 34   "Un: Bertolli 500g" 35   "Un: Flora buttery 500g" 36   "Un: Flora extra light 500g" 37   "Un: Flora light 500g" 38   "Un: Flora light 1kg" 39   "Un: Flora proactive 250g" 40   "Un: Flora proactive 500g" 41   "Un: Flora 500g" 42   "Un: Flora 1kg" 43   "Un: ICBINB 1kg" 44   "Un: ICBINB 500g" 45   "Un: ICBINB light 500g" 46   "Un: Stork 250g" 47   "Un: Stork 500g" 48   "Un: Stork 1kg"
lab val prod prod

**Table B.1
tabout prod using "$G\priceelas_cubic.tex", replace sum bt ptotal(none) format(4 4 4 4 4 4 4 4 4 4 4 4) cells(mean v5 mean v10 mean v11 mean v15 mean v21 mean v35 mean v37 mean v44 mean v45 mean v47 mean v1) style(tex) h1(nil) h2(& Ar: Anchor & Ar: Lurpak  & Ar: Lurpak  & DC: Clover & DC: Utterly  & Un: Flora & Un: Flora  & Un: ICBINB  & Un: ICBINB  & Un: Stork  & Outside \\) h3(& NZ 500g & spread ss 500g & light ss 500g & spread 500g & Butterly 500g & buttery 500g & light 500g & 500g & Light 500g & 500g & option \\)

insheet using "$M/melas_linear.raw",clear

gen prodcode = _n
drop v49
order prodcode

merge 1:1 prodcode using "$DL/product_results.dta"

keep if prodcode==5|prodcode==10|prodcode==11|prodcode==15|prodcode==21|prodcode==35|prodcode==37|prodcode==44|prodcode==45|prodcode==47|prodcode==1
drop if prodcode==1
keep prodcode v1 v5 v10 v11 v15 v21 v35 v37 v44 v45 v47

cap lab def prod  1 "Outside option" 2   "Kerrygold 250g" 3   "Ar: Anchor 250g" 4   "Ar: Anchor NZ 250g" 5   "Ar: Anchor NZ 500g" 6   "Ar: Anchor light NZ 500g" 7   "Ar: Lurpak ss 250g"   8   "Ar: Lurpak us 250g" 9   "Ar: Lurpak spread ss 250g" 10   "Ar: Lurpak spread ss 500g" 11   "Ar: Lurpak light ss 500g" 12   "Ar: Lurpak light ss 250g" 13   "Asda 250g" 14   "DC: Clover diet 500g" 15   "DC: Clover spread 500g" 16   "DC: Clover spread 1kg" 17   "DC: Country life 250g" 18   "DC: Country life us 250g" 19   "DC: Country life light 500g" 20   "DC: Country life spread 500g" 21   "DC: Utterly Butterly 500g" 22   "DC: Utterly Butterly 1kg" 23   "DC: Vitalite 500g" 24   "DC: Willow 250g" 25   "Sainsburys 250g" 26   "Sainsburys us 250g" 27   "Morrisons 250g" 28   "Tesco butter me up 500g" 29   "Tesco blended 250g" 30   "Tesco value 250g" 31   "Tesco value us 250g" 32   "Un: Bertolli light 500g" 33   "Un: Bertolli 1kg" 34   "Un: Bertolli 500g" 35   "Un: Flora buttery 500g" 36   "Un: Flora extra light 500g" 37   "Un: Flora light 500g" 38   "Un: Flora light 1kg" 39   "Un: Flora proactive 250g" 40   "Un: Flora proactive 500g" 41   "Un: Flora 500g" 42   "Un: Flora 1kg" 43   "Un: ICBINB 1kg" 44   "Un: ICBINB 500g" 45   "Un: ICBINB light 500g" 46   "Un: Stork 250g" 47   "Un: Stork 500g" 48   "Un: Stork 1kg"
lab val prod prod

**Table B.1
tabout prod using "$G\priceelas_lin.tex", replace sum bt ptotal(none) format(4 4 4 4 4 4 4 4 4 4 4 4) cells(mean v5 mean v10 mean v11 mean v15 mean v21 mean v35 mean v37 mean v44 mean v45 mean v47 mean v1) style(tex) h1(nil) h2(& Ar: Anchor & Ar: Lurpak  & Ar: Lurpak  & DC: Clover & DC: Utterly  & Un: Flora & Un: Flora  & Un: ICBINB  & Un: ICBINB  & Un: Stork  & Outside \\) h3(& NZ 500g & spread ss 500g & light ss 500g & spread 500g & Butterly 500g & buttery 500g & light 500g & 500g & Light 500g & 500g & option \\)

insheet using "$M/melas_prefshift.raw",clear

gen prodcode = _n
drop v49
order prodcode

merge 1:1 prodcode using "$DP/product_results.dta"

keep if prodcode==5|prodcode==10|prodcode==11|prodcode==15|prodcode==21|prodcode==35|prodcode==37|prodcode==44|prodcode==45|prodcode==47|prodcode==1
drop if prodcode==1
keep prodcode v1 v5 v10 v11 v15 v21 v35 v37 v44 v45 v47


cap lab def prod  1 "Outside option" 2   "Kerrygold 250g" 3   "Ar: Anchor 250g" 4   "Ar: Anchor NZ 250g" 5   "Ar: Anchor NZ 500g" 6   "Ar: Anchor light NZ 500g" 7   "Ar: Lurpak ss 250g"   8   "Ar: Lurpak us 250g" 9   "Ar: Lurpak spread ss 250g" 10   "Ar: Lurpak spread ss 500g" 11   "Ar: Lurpak light ss 500g" 12   "Ar: Lurpak light ss 250g" 13   "Asda 250g" 14   "DC: Clover diet 500g" 15   "DC: Clover spread 500g" 16   "DC: Clover spread 1kg" 17   "DC: Country life 250g" 18   "DC: Country life us 250g" 19   "DC: Country life light 500g" 20   "DC: Country life spread 500g" 21   "DC: Utterly Butterly 500g" 22   "DC: Utterly Butterly 1kg" 23   "DC: Vitalite 500g" 24   "DC: Willow 250g" 25   "Sainsburys 250g" 26   "Sainsburys us 250g" 27   "Morrisons 250g" 28   "Tesco butter me up 500g" 29   "Tesco blended 250g" 30   "Tesco value 250g" 31   "Tesco value us 250g" 32   "Un: Bertolli light 500g" 33   "Un: Bertolli 1kg" 34   "Un: Bertolli 500g" 35   "Un: Flora buttery 500g" 36   "Un: Flora extra light 500g" 37   "Un: Flora light 500g" 38   "Un: Flora light 1kg" 39   "Un: Flora proactive 250g" 40   "Un: Flora proactive 500g" 41   "Un: Flora 500g" 42   "Un: Flora 1kg" 43   "Un: ICBINB 1kg" 44   "Un: ICBINB 500g" 45   "Un: ICBINB light 500g" 46   "Un: Stork 250g" 47   "Un: Stork 500g" 48   "Un: Stork 1kg"
lab val prod prod

**Table B.1
tabout prod using "$G\priceelas_pref.tex", replace sum bt ptotal(none) format(4 4 4 4 4 4 4 4 4 4 4 4) cells(mean v5 mean v10 mean v11 mean v15 mean v21 mean v35 mean v37 mean v44 mean v45 mean v47 mean v1) style(tex) h1(nil) h2(& Ar: Anchor & Ar: Lurpak  & Ar: Lurpak  & DC: Clover & DC: Utterly  & Un: Flora & Un: Flora  & Un: ICBINB  & Un: ICBINB  & Un: Stork  & Outside \\) h3(& NZ 500g & spread ss 500g & light ss 500g & spread 500g & Butterly 500g & buttery 500g & light 500g & 500g & Light 500g & 500g & option \\)

**Costs

u "$DN/Product_results.dta",clear

lab def prod 1   "Outside option" 2   "Kerrygold 250g" 3   "Ar: Anchor 250g" 4   "Ar: Anchor NZ 250g" 5   "Ar: Anchor NZ 500g" 6   "Ar: Anchor light NZ 500g" 7   "Ar: Lurpak ss 250g"   8   "Ar: Lurpak us 250g" 9   "Ar: Lurpak spread ss 250g" 10   "Ar: Lurpak spread ss 500g" 11   "Ar: Lurpak light ss 500g" 12   "Ar: Lurpak light ss 250g" 13   "Asda 250g" 14   "DC: Clover diet 500g" 15   "DC: Clover spread 500g" 16   "DC: Clover spread 1kg" 17   "DC: Country life 250g" 18   "DC: Country life us 250g" 19   "DC: Country life light 500g" 20   "DC: Country life spread 500g" 21   "DC: Utterly Butterly 500g" 22   "DC: Utterly Butterly 1kg" 23   "DC: Vitalite 500g" 24   "DC: Willow 250g" 25   "Sainsburys 250g" 26   "Sainsburys us 250g" 27   "Morrisons 250g" 28   "Tesco butter me up 500g" 29   "Tesco blended 250g" 30   "Tesco value 250g" 31   "Tesco value us 250g" 32   "Un: Bertolli light 500g" 33   "Un: Bertolli 1kg" 34   "Un: Bertolli 500g" 35   "Un: Flora buttery 500g" 36   "Un: Flora extra light 500g" 37   "Un: Flora light 500g" 38   "Un: Flora light 1kg" 39   "Un: Flora proactive 250g" 40   "Un: Flora proactive 500g" 41   "Un: Flora 500g" 42   "Un: Flora 1kg" 43   "Un: ICBINB 1kg" 44   "Un: ICBINB 500g" 45   "Un: ICBINB light 500g" 46   "Un: Stork 250g" 47   "Un: Stork 500g" 48   "Un: Stork 1kg"
lab val prodcode prod

gen temp = -share_basemulti
egen temp2 = rank(temp)

keep if temp2<12
drop if prodcode==1

keep prodcode price_basemulti cost margin_basemulti
rename price_basemulti  price_nonl
rename cost             cost_nonl
rename margin_basemulti margin_nonl

sa "$P/costs_nonl.dta",replace

u "$DL/Product_results.dta",clear

lab val prodcode prod

keep if prodcode==5|prodcode==10|prodcode==11|prodcode==15|prodcode==21|prodcode==35|prodcode==37|prodcode==44|prodcode==45|prodcode==47|prodcode==1
drop if prodcode==1

keep prodcode price_basemulti cost margin_basemulti
rename price_basemulti  price_lin
rename cost             cost_lin
rename margin_basemulti margin_lin

sa "$P/costs_lin.dta",replace

u "$DP/Product_results.dta",clear

lab val prodcode prod

keep if prodcode==5|prodcode==10|prodcode==11|prodcode==15|prodcode==21|prodcode==35|prodcode==37|prodcode==44|prodcode==45|prodcode==47|prodcode==1
drop if prodcode==1

keep prodcode price_basemulti cost margin_basemulti
rename price_basemulti  price_pref
rename cost             cost_pref
rename margin_basemulti margin_pref

merge 1:1 prodcode using "$P/costs_nonl.dta"
drop _m
merge 1:1 prodcode using "$P/costs_lin.dta"
drop _m

**Table B.2
tabout prodc using "$G\costs.tex", replace sum bt ptotal(none) format(2 2 2 2 2 2 2) cells(mean price_non mean cost_non mean margin_non mean cost_lin mean margin_lin mean cost_pref mean margin_pref) style(tex) h1(nil) h2(nil) h3(& Price & Cost & Margin & Cost & Margin & Cost & Margin \\)
